<!DOCTYPE html>
<html class="no-js" lang="{{ request.locale_name }}" prefix="dcat: http://www.w3.org/TR/vocab-dcat/">

{% set app_package = app_package|default('atramhasis', true) -%}
{% set app_name = app_name|default('Atramhasis') %}
{% set copyright_year = '2014-2023' %}

<head>
{% block head %}
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <title>{{ app_name }} - {% block html_title %}Base{% endblock %}</title>

  {% block css_files %}
    <link rel="stylesheet" href="{{request.static_path(app_package + ':static/css/app.css')}}" />
    <link rel="stylesheet" href="{{request.static_path(app_package + ':static/css/print.css')}}" media="print" />
  {% endblock %}

  {% if request.registry.settings['atramhasis.ldf.enabled'] %}
    <link rel="dcat:distribution" href="{{request.registry.settings['atramhasis.ldf.baseurl']}}" />
  {% endif %}

  <link rel="icon" type="image/x-icon" href="{{request.static_path(app_package + ':static/img/favicon.ico')}}" />
  <script src="{{request.static_path(app_package + ':static/node_modules/foundation-sites/js/vendor/modernizr.js')}}"></script>

  {% block js_files_head %}
    <script src="{{ request.static_path(app_package + ':static/node_modules/foundation-sites/js/vendor/jquery.js') }}"></script>
    <script src="{{ request.static_path(app_package + ':static/node_modules/foundation-sites/js/vendor/jquery.cookie.js') }}"></script>
  {% endblock %}
{% endblock %}
</head>
<body>
{% block vl_header %}
{% endblock %}

{% block header %}
{% endblock %}

{% block content %}
{% endblock %}

{% block subfooter %}
{% endblock %}

{% block footer %}
{% endblock %}

{% block js_files %}
  <script src="{{request.static_path(app_package + ':static/node_modules/foundation-sites/js/vendor/fastclick.js')}}"></script>
  <script src="{{ request.static_path(app_package + ':static/node_modules/foundation-sites/js/foundation.min.js') }}"></script>
  <script src="{{ request.static_path(app_package + ':static/js/app.js') }}"></script>
{% endblock %}

{% block vl_footer %}
{% endblock %}

{% block custom_js %}{% endblock %}
</body>
</html>
