{% from "macros.jinja2" import
	get_language_links
  %}
<div class="row">
  <footer class="footerpage">
    <div style="margin-bottom: 10px;">{{ get_language_links(request) }}</div>
    <small> &copy; Copyright {{ copyright_year }} <a href="https://www.onroerenderfgoed.be/">Flanders Heritage Agency</a></small>
  </footer>
</div>
