EVENTTYPESDATA = [
    {
        "broader": [],
        "id": 120,
        "labels": [{"label": "actualisaties", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [118],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een actualisatie in het kader van erfgoedadministratie is het"
                    " aanpassen van administratieve gegevens (locatie, status)  op"
                    " basis van plaatsbezoek."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "agentschap Onroerend Erfgoed", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [35],
        "id": 66,
        "labels": [
            {"label": "ad hoc-inventarisatie", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 119,
        "labels": [{"label": "adrescontroles", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [118],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een adrescontrole in het kader van erfgoedadministratie is het"
                    " aanpassen van administratieve gegevens (locatie, status) op basis"
                    " van desktop onderzoek (raadplegen CRAB, GIS, ...)"
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "agentschap Onroerend Erfgoed", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 125,
        "labels": [
            {
                "label": "afbakenen erfgoedlandschappen",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [122],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [8],
        "id": 11,
        "labels": [
            {
                "label": "analyse digitaal hoogtemodel",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Analyse van het digitaal hoogtemodel (ook wel hoogtemodellering)"
                    " is het bestuderen van een digitaal hoogtemodel (DHM, DTM of DEM)"
                    " - een digitale weergave van de oppervlaktetopografie van een"
                    " terrein - om sites op te sporen die zich uiten door (kleine)"
                    " verschillen in het reli\xebf (bijvoorbeeld grafheuvels, grachten"
                    " en wallen, mottes, celtic fields, sites met walgracht, ...)."
                    " Zowel absolute hoogteligging als de terreinvorm spelen bovendien"
                    " een grote rol bij het kiezen van een locatie voor een"
                    " nederzetting. Hoogtemodellering wordt ook gebruikt voor het"
                    " onderzoek van het historisch landschap."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [99],
        "id": 107,
        "labels": [
            {
                "label": "anthracologisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "houtskoolonderzoek", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Bij onderzoek van houtskool wordt in de eerste plaats bepaald"
                    " welke houtsoort het betreft. Het is belangrijk na te gaan welke"
                    " houtsoorten voor welke toepassingen werden gebruikt. Het"
                    " onderzoek van houtskool kan ook informatie geven over hoe het"
                    " landschap en de vegetatie in het verleden eruit zagen. Houtskool"
                    " kan ook gebruikt worden voor het dateren van archeologische"
                    " contexten, objecten of constructies."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 2) 9.2.4. Hout en houtskool, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                ),
                "type": "note",
            },
        ],
        "related": [84, 89, 106],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [82],
        "id": 99,
        "labels": [
            {
                "label": "archeobotanisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [100, 101, 104, 106, 107],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Archeobotanisch onderzoek is het onderzoek van plantaardige resten"
                    " in het kader van archeologisch onderzoek."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 38,
        "labels": [
            {
                "label": "archeologische opgravingen",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een archeologische opgraving is het blootleggen (per definitie"
                    " destructief) van een vindplaats met als doel het documenteren van"
                    " gegevens en het veiligstellen van materiaal om daarmee informatie"
                    " te behouden die van belang is voor kennisvorming over het"
                    " verleden. Bij een opgraving wordt getracht een compromis te"
                    " vinden tussen registreren in plan (horizontaal) en aan de hand"
                    " van de stratigrafie (verticaal). Een opgraving moet steeds"
                    " vergund worden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Kwaliteitsnorm Nederlandse Archeologie (KNA - Verklarende"
                    " Woordenlijst) 2) Carver M. 1999, Fieldarchaeology, in: G. Barker"
                    " (ed.), Companion Encyclopedia of Archaeology, pp. 128-181. 3)"
                    " Renfrew C. &amp; Bahn P. 2000, Archaeology: Theories, Methods and"
                    " Practice, London."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [67, 70, 75],
        "type": "concept",
    },
    {
        "broader": [14],
        "id": 40,
        "labels": [
            {
                "label": "archeologische prospectie",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [41, 44, 51],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Prospectie is het opsporen van archeologisch erfgoed, het"
                    " identificeren ervan (datering, aard van de sporen en vondsten,"
                    " enz.), en het evalueren van het wetenschappelijk interpretatief"
                    " potentieel (zowel qua bewaringsconditie als informatie\xadwaarde)"
                    " met een minimum aan destructie van het archeologisch erfgoed."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Minimumnormen Vlaamse archeologie (A. Ervynck) 2) Groenewoudt"
                    " B.J. 1994, Prospectie, waardering en selectie van archeologische"
                    " vindplaatsen: een beleidsgerichte verkenning van middelen en"
                    " mogelijkheden, Nederlandse Archeologische Rapporten 17,"
                    " Amersfoort."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [40],
        "id": 41,
        "labels": [
            {
                "label": "archeologische prospectie met ingreep in de bodem",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "proefonderzoek", "language": "nl", "type": "altLabel"},
            {"label": "proefsleuvenonderzoek", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Archeologische prospectie met ingreep in de bodem is een"
                    " evaluerend onderzoek waarbij de waarde van de site moet ingeschat"
                    " worden aan de hand van kleine ingrepen in de bodem, zonder"
                    " daadwerkelijk over te gaan tot een opgraving. Het betreft een"
                    " ingreep van beperkte omvang op een of meerdere beperkte locaties"
                    " binnen een vindplaats (proefput) dan wel in de vorm van een of"
                    " meerdere sleuven (proefsleuf) om nadere gegevens te verzamelen"
                    " over aard, omvang, diepteligging e.d. van de grondsporen, waarbij"
                    " de grondsporen zo veel mogelijk intact worden gelaten. Dergelijk"
                    " onderzoek kan noodzakelijk zijn in het kader van een"
                    " inventariserend veldonderzoek, maar dient met name ter"
                    " voorbereiding van de opgraving. Prospectie met ingreep in de"
                    " bodem moet steeds vergund worden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Kwaliteitsnorm Nederlandse Archeologie (KNA - Verklarende"
                    " Woordenlijst) 2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [76],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [40],
        "id": 44,
        "labels": [
            {
                "label": "archeologische veldprospectie",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "archeologische veldprospectie twee",
                "language": "nl",
                "type": "altLabel",
            },
            {"label": "fieldwalking", "language": "nl", "type": "altLabel"},
            {"label": "oppervlaktekartering", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [48, 49],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Bij veldkartering worden terreinen bewandeld op de aanwezigheid"
                    " van (concentraties) archeologische indicatoren aan de"
                    " oppervlakte. Hierbij wordt de verspreiding van archaeologica die"
                    " verstoord zijn uit hun begraven contexten in kaart gebracht en"
                    " worden de archaeologica zelf indien mogelijk ingezameld."
                    " Dergelijk onderzoek kan systematisch (in raaien of rasters op"
                    " gelijke afstanden) of niet-systematisch (random walking)"
                    " gebeuren. Vaak wordt een GPS gebruikt voor het lokaliseren van de"
                    " geprospecteerde eenheden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) 12.2.4. Veldkartering, in: Onderzoeksbalans Onroerend Erfgoed"
                    " Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                    " 2) Carver M. 1999, Fieldarchaeology, in: G. Barker (ed.),"
                    " Companion Encyclopedia of Archaeology, pp. 128-181. 3) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [15],
        "id": 137,
        "labels": [
            {
                "label": "archeologisch verkennend booronderzoek",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "prospectief booronderzoek",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Het archeologisch verkennend (karterend of prospectief)"
                    " booronderzoek heeft als doel archeologische vindplaatsen op te"
                    " sporen en een eerste inschatting maken van de mogelijke aard,"
                    " datering, afbakening, en conservatie. \nDit gebeurt door een"
                    " gerichte monstername van sedimenten te zeven en te onderzoeken op"
                    " archeologische indicatoren."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "Onroerend Erfgoed", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [15],
        "id": 138,
        "labels": [
            {
                "label": "archeologisch waarderend booronderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Het archeologisch waarderend booronderzoek heeft als doelstelling"
                    " herkende vindplaatsen nader te evalueren."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "Onroerend Erfgoed", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [83],
        "id": 85,
        "labels": [
            {
                "label": "archeomagnetische datering",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "archeomagnetisch onderzoek",
                "language": "nl",
                "type": "altLabel",
            },
            {"label": "archeomagnetisme", "language": "nl", "type": "altLabel"},
            {"label": "paleomagnetisme", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Archeomagnetisme steunt op het feit dat het aardmagnetisch veld"
                    " niet steeds dezelfde ori\xebntatie behoudt, maar dat deze"
                    " varieert in de tijd. Het magnetisch noorden en het geografisch"
                    " noorden liggen niet op exact dezelfde locatie en bovendien"
                    " varieert ook de afwijking tussen de twee doorheen de tijd. Het"
                    " verschil tussen beide kan beschreven worden aan de hand van de"
                    " inclinatie en declinatie. Het archeomagnetische veld kan bewaard"
                    " worden in archeologische objecten, sedimenten en magnetische"
                    " mineralen. Kleimineralen die magnetische ijzeroxiden bevatten,"
                    " verliezen boven een bepaalde temperatuur hun magnetische"
                    " eigenschappen en nemen de magnetische richting en intensiteit aan"
                    " van het op dat moment heersende aardmagnetisch veld. Men kan deze"
                    " parameters vervolgens vergelijken met de actuele waarden. Uit"
                    " analyse van materiaal met gekende oorsprongsdatum zijn curven"
                    " opgesteld die voor een bepaalde plaats op aarde de inclinatie en"
                    " declinatie doorheen de tijd weergeven. Als men de waarden van een"
                    " archeologisch staal op een dergelijke curve uitzet, kan een"
                    " datering verkregen worden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 81,
        "labels": [{"label": "archeometrie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [83, 96],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Archeometrisch onderzoek is onderzoek dat zich bezighoudt met het"
                    " analyseren van archeologische monsters door middel van"
                    " wetenschappelijke technieken."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [82],
        "id": 109,
        "labels": [
            {
                "label": "archeozo\xf6logisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "zo\xf6archeologisch onderzoek",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [111, 112],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Archeozo\xf6logisch onderzoek is de studie van dierlijke resten en"
                    " sporen uit opgravingen. Deze studie geeft informatie over de"
                    " dierenwereld van vroeger en vooral over de wijze waarop de mens"
                    " die exploiteerde en welke de voedingspatronen waren. Het gaat"
                    " hierbij niet enkel om lichaamsresten van dieren"
                    " (skeletmateriaal), maar ook om alle sporen die ze bij hun"
                    " activiteit hebben achtergelaten. Het kan hierbij gaan om"
                    " pootafdrukken, bijtsporen, bioturbatie en zelfs coprolieten."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 2) 9.3. Archeozo\xf6logisch onderzoek, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 5,
        "labels": [
            {"label": "archiefonderzoek", "language": "nl", "type": "prefLabel"},
            {"label": "archivalisch onderzoek", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Archiefonderzoek omvat onderzoek in een archief (bestaat uit"
                    " documenten die een bepaalde organisatie, familie en persoon"
                    " voortbrengt of ontvangt om aan te tonen dat die zijn/haar"
                    " opdracht goed uitvoert of bepaalde rechten kan laten gelden). In"
                    " de archeologische wereld heb je meestal archieven van"
                    " instellingen (overheid, universiteiten) of priv\xe9-personen"
                    " (verzamelaars) die opgravingen hebben verricht en hebben"
                    " gedocumenteerd."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 139,
        "labels": [{"label": "assessment", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een assessment is een inschatting van het wetenschappelijk"
                    " potentieel of de informatiewaarde van een archeologische"
                    " vondstcategorie."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Minimumnormen voor de registratie en documentatie bij"
                    " archeologisch onderzoek met ingreep in de bodem en de wijze van"
                    " rapportering"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2],
        "id": 116,
        "labels": [{"label": "baggervondsten", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een baggervondst is een vondst gedaan tijdens het uitbaggeren van"
                    " een rivier."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 123,
        "labels": [{"label": "beschermingen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [122],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [96],
        "id": 97,
        "labels": [
            {
                "label": "biochemische analytische methoden",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Biochemische analytische methoden zijn methoden waarvan de werking"
                    " steunt op biochemische fenomenen. Onderzoek dat hieronder valt"
                    " omvat onder andere residu-analyse, DNA-analyse, isotopenanalysen"
                    " met het oog op dieetreconstructies en dergelijke meer."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [14],
        "id": 15,
        "labels": [{"label": "booronderzoek", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [16, 136, 137, 138],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Karteringsmethode bij veldinventarisatie, gebaseerd op het"
                    " verrichten van grondboringen, waarbij vooral wordt gelet op het"
                    " voorkomen van archeologische indicaties zoals"
                    " aardewerkfragmenten, houtskool en fosfaatconcentraties door"
                    " middel van een al dan niet systematische bemonstering van de"
                    " bodem. Voor bepaalde periodes (prehistorie) kan deze techniek"
                    " gebruikt worden om sites op te sporen. Voor andere periodes"
                    " worden boringen voornamelijk gebruikt om de mogelijke verstoring"
                    " van de bodemlagen na te gaan in aanloop van verder onderzoek."
                    " Booronderzoek kan ook gebruikt worden om het"
                    " prehistorisch/historisch landschap te reconstrueren aan de hand"
                    " van beschrijvingen van boorprofielen, bestuderen van bodemopbouw"
                    " en bodemstructuur,...."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Kwaliteitsnorm Nederlandse Archeologie (KNA - Verklarende"
                    " Woordenlijst) 2) Groenewoudt B.J. 1994, Prospectie, waardering en"
                    " selectie van archeologische vindplaatsen: een beleidsgerichte"
                    " verkenning van middelen en mogelijkheden, Nederlandse"
                    " Archeologische Rapporten 17, Amersfoort."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [36],
        "id": 37,
        "labels": [
            {"label": "bouwblokonderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 36,
        "labels": [
            {"label": "bouwhistorisch onderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [37],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Bouwhistorisch onderzoek houdt zich bezig met lezen van gebouwen"
                    " in hun materi\xeble context aan de hand van opstaande"
                    " muurverbanden. Dergelijk onderzoek geeft in de eerste plaats"
                    " beschrijvende informatie over het gebouw in kwestie en"
                    " historische bouwtechnieken, gebruikte materialen,"
                    " baksteenformaties en metselverbanden, maar kan ook gebruikt"
                    " worden voor het dateren van muurwerk."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [32],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 8,
        "labels": [{"label": "bureauonderzoek", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [9, 10, 11, 12, 13],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Bureauonderzoek is het verwerven van informatie, aan de hand van"
                    " bestaande bronnen, over bekende of verwachte bouwkundige of"
                    " archeologische waarden binnen een onderzoeksgebied, omvattende de"
                    " aan- of afwezigheid, de aard en de omvang, de datering, gaafheid"
                    " en conservering en de relatieve kwaliteit ervan."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Kwaliteitsnorm Nederlandse Archeologie (KNA - Verklarende"
                    " woordenlijst).\n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 4,
        "labels": [{"label": "conservatie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [117],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Behoud, bewaring en instandhouding van bouwkundige en"
                    " archeologische relicten en objecten."
                ),
                "type": "definition",
            }
        ],
        "related": [3],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [40],
        "id": 51,
        "labels": [
            {"label": "controle van werken", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een controle van werken houdt in dat niet-archeologisch"
                    " gerelateerde werken worden gecontroleerd op de aanwezigheid van"
                    " archeologische resten. Dit kan in de vorm van een werfcontrole,"
                    " een opvolging van werken, herstellingswerkzaamheden e.d. De"
                    " huidige procedure voor de controle van werken gaat gepaard met"
                    " een vergunning."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [81],
        "id": 83,
        "labels": [
            {"label": "dateringsonderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [84, 85, 89, 91, 94],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [83],
        "id": 89,
        "labels": [
            {
                "label": "dendrochronologisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "dendrochronologie", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Dendrochronologisch onderzoek is jaarringonderzoek van"
                    " houtmonsters. De techniek steunt op het feit dat bomen die"
                    " groeien in verschillende delen van de aarde, gekenmerkt door"
                    " duidelijke seizoensverschillen, patronen produceren ten gevolge"
                    " van verschillen in groeisnelheid. Op deze manier ontstaan"
                    " groeiringen. Aan de hand daarvan is het vaak mogelijk om tot een"
                    " precieze en betrouwbare datering van een structuur of object te"
                    " komen. De jaarringen van de monsters worden nauwkeurig gemeten en"
                    " vergeleken met gemiddelde en reeds gedateerde waarden, de zgn."
                    " referentiecurven. De datering geeft het jaar weer waarin de boom"
                    " gekapt werd; men moet dus rekening houden met verlengd gebruik."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 2) Haslinghuis E.J. &amp; Janse H. 1997,"
                    " Bouwkundige termen. Verklarend woordenboek van de westerse"
                    " architectuur- en bouwhistorie, Leiden."
                ),
                "type": "note",
            },
        ],
        "related": [106, 107],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [49],
        "id": 50,
        "labels": [{"label": "detailkartering", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Detailkartering is een vorm van veldprospectie waarbij gewerkt"
                    " wordt in een rasterpatroon en het materiaal per rastercel wordt"
                    " verzameld. Deze methode wordt meestal gebruikt voor sites waarvan"
                    " men het bestaan reeds kent en heeft niet zozeer opsporen tot"
                    " doel, maar eerder waardering."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) 12.2.4. Veldkartering, in: Onderzoeksbalans Onroerend Erfgoed"
                    " Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                    " 2) Groenewoudt B.J. 1994, Prospectie, waardering en selectie van"
                    " archeologische vindplaatsen: een beleidsgerichte verkenning van"
                    " middelen en mogelijkheden, Nederlandse Archeologische Rapporten"
                    " 17, Amersfoort."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [99],
        "id": 100,
        "labels": [
            {"label": "diatomee\xebnonderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Diatomee\xebn zijn eencellige wiertjes die gekenmerkt worden door"
                    " een skelet in de celwand, opgebouwd uit silicaat. Vanwege hun"
                    " resistent skelet kunnen deze wiertjes na afsterven worden"
                    " opgenomen in het sediment en fossiliseren. Studie van soorten"
                    " diatomee\xebn kan informatie verstrekken over sedimenttransport"
                    " of over hydrogeografische of geomorfologische fenomenen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 82,
        "labels": [
            {"label": "ecologische archeologie", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [99, 109, 115],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Ecologische archeologie is de studie van de interactie tussen de"
                    " mens en zijn omgeving doorheen de tijd, hoofdzakelijk aan de hand"
                    " van benaderingen vanuit geografie, geologie en biologie."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 22,
        "labels": [
            {
                "label": "elektrische weerstandsmeting",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "elektrische resistiviteitsmeting",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Elektrische weerstandmeting of elektrische resistiviteitsmeting"
                    " (ER) gebeurt door een elektrische stroom via elektroden in de"
                    " bodem te brengen, waarbij de elektrische weerstand tussen de"
                    " elektroden wordt gemeten. Deze weerstand is afhankelijk van het"
                    " vochtgehalte in de bodem. Archeologische sporen kunnen"
                    " anomalie\xebn in de weerstand veroorzaken, vooral wanneer er een"
                    " verschil is in vochtretentie. Vooral muren en andere stenen"
                    " concentraties zijn goed op te sporen. Elektrische tomografie"
                    " maakt gebruik van dezelfde principes, maar gebruikt hiervoor een"
                    " tomograaf die een verticale doorsnede van de bodem maakt."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) 12.2.3. Geofysische en geochemische onderzoeksmethoden, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                    " 2) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 3) Renfrew C. &amp; Bahn P. 2000,"
                    " Archaeology: Theories, Methods and Practice, London."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 24,
        "labels": [
            {
                "label": "elektromagnetisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Elektromagnetisch onderzoek maakt gebruik van elektromagnetische"
                    " inductie om elektrische conductiviteit (geleidbaarheid) van de"
                    " bodem in kaart te brengen en op die manier archeologische"
                    " structuren op te sporen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "National Monuments Record thesaurus (English Heritage), <a"
                    ' href="https://thesaurus.english-heritage.org.uk/frequentuser.htm">https://thesaurus.english-heritage.org.uk/frequentuser.htm</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "id": 122,
        "labels": [
            {"label": "erfgoedaanduiding", "language": "nl", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [123, 124, 125],
        "notes": [],
        "superordinates": [],
        "type": "collection",
    },
    {
        "id": 118,
        "labels": [
            {"label": "erfgoedadministratie", "language": "nl", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [119, 120, 121],
        "notes": [],
        "superordinates": [],
        "type": "collection",
    },
    {
        "id": 117,
        "labels": [{"label": "erfgoedbeheer", "language": "nl", "type": "prefLabel"}],
        "member_of": [],
        "members": [3, 4, 31],
        "notes": [],
        "superordinates": [],
        "type": "collection",
    },
    {
        "broader": [],
        "id": 1,
        "labels": [
            {"label": "erfgoedonderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [33, 34, 35, 36, 39, 38],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 33,
        "labels": [
            {"label": "evaluerend onderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [5, 6, 8, 14, 53, 139],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 132,
        "labels": [
            {"label": "forensische archeologie", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Forensische archeologie houdt zich bezig met het onderzoek en"
                    " herkenning, vastlegging en bemonstering van bodemkundige,"
                    " botanische en entomologische sporen, zodat deze tijdens een"
                    " vervolgonderzoek betrouwbaar kunnen worden ingezet voor het"
                    " reconstrueren en dateren van een gebeurtenis. Meer specifiek"
                    " wordt forensische archeologie veelal ingeschakeld bij het"
                    " onderzoeken van mogelijke plaatsen van misdaad en het onderzoeken"
                    " van graven en lijken."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Website Nederlands Forensisch Instituut (NFI)\n2) Onroerend"
                    " Erfgoed"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [18],
        "id": 19,
        "labels": [
            {"label": "fosfaatanalyse", "language": "nl", "type": "prefLabel"},
            {"label": "fosfaatkartering", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Fosfaatanalyse is gebaseerd op het feit dat menselijke activiteit"
                    " (en bijgevolg ook de aanwezigheid van dieren en planten in"
                    " functie van deze activiteit) een verhoging in het fosfaatgehalte"
                    " van de bodem kan veroorzaken. De toepassing wordt gebruikt om de"
                    " functie van bepaalde ruimtes/delen van de site te verduidelijken"
                    " (bv. stallen) of om op sites waar geen duidelijke architecturale"
                    " sporen zijn, toch de bewoning te kunnen lokaliseren."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) 12.2.3. Geofysische en geochemische onderzoeksmethoden, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                    " 2) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 3) Renfrew C. &amp; Bahn P. 2000,"
                    " Archaeology: Theories, Methods and Practice, London."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [14],
        "id": 52,
        "labels": [
            {
                "label": "fotogrammetrisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Fotogrammetrisch onderzoek is het onderzoek door metingen uit te"
                    " voeren op luchtfoto's en het uitvoeren van 3D-analyses. De"
                    " techniek kan ook toegepast worden op nog opstaande gebouwen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": "Mogelijk SN nog aanvullen",
                "type": "historyNote",
            },
            {
                "language": "nl",
                "note": (
                    "1) S.n. 2005, De aarde van op afstand bekeken, in: Nieuwsbrief"
                    " GIS-Vlaanderen (juni 2005, nr. 19). 2) Goossens R. 2003, 3D"
                    " analysis of satellite images for archaeology, in: J. Bourgeois"
                    " &amp; M. Meganck (eds.), Aerial photography and archaeology 2003."
                    " A century of information, Archaeological Reports Ghent University"
                    " 4, Gent. \n3) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [96],
        "id": 98,
        "labels": [
            {
                "label": "fysico-chemische analytische methoden",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Fysico-chemische analytische methoden zijn methoden waarvan de"
                    " werking steunt op natuurkundige en/of scheikundige fenomenen."
                    " Hieronder vallen beeldvormingsmethoden (a.d.h.v. zichtbaar licht,"
                    " infrarood, UV, X-ray en scanning-elektronenmicroscopie),"
                    " spectroscopische methoden (a.d.h.v. zichtbaar licht, infrarood,"
                    " UV-fluorescentie, X-stralenfluorescentie, Ramanspectroscopie,"
                    " scanning-elektronenmicroscopie, proton-ge\xefnduceerde"
                    " X-stralenemissie en neutronenactiveringsanalyse),"
                    " scheidingsmethoden (chromatografische technieken) en enkele"
                    " andere methoden zoals X-stralendiffractie en massaspectrometrie."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [81],
        "id": 96,
        "labels": [
            {
                "label": "fysico-chemische en biochemische analytische methoden",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [97, 98],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [82],
        "id": 115,
        "labels": [
            {
                "label": "fysisch-antropologisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Fysisch-antropologisch onderzoek is het onderzoek van menselijke"
                    " skelet- en crematieresten en begravingssporen aangetroffen bij"
                    " archeologische opgravingen. Studie van de biologische"
                    " eigenschappen van beenderen verschaft inzicht in de"
                    " sterfteleeftijd en het geslacht, de lichaamslengte, bepaalde"
                    " erfelijke kenmerken, de gezondheidstoestand, hygi\xebne en"
                    " voedingsgewoontes van een individu."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 2) 9.4. Fysisch-antropologisch onderzoek,"
                    " in: Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [39],
        "id": 78,
        "labels": [
            {"label": "gebruikssporenanalyse", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Gebruikssporenanalyse analyseert het oppervlak en de randen van"
                    " een artefact op gebruikssporen (beschadiging en residu), meestal"
                    " aan de hand van een sterke microscoop. De techniek wordt"
                    " voornamelijk toegepast bij de studie van stenen werktuigen waarop"
                    " herkenbare beschadiging of polijsting te zien is door gebruik"
                    " voor het snijden, zagen, doorboren van andere materialen, maar"
                    " ook andere objectgroepen kunnen geanalyseerd worden op"
                    " gebruikssporen (bv. slijtagesporen op aardewerk)."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [14],
        "id": 18,
        "labels": [
            {"label": "geochemisch onderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [19],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Geochemisch onderzoek berust op het feit dat menselijke activiteit"
                    " (en bijgevolg ook de aanwezigheid van dieren en planten in"
                    " functie van deze activiteit) wijzigingen in de chemische"
                    " samenstelling van de bodem geeft bv. door organische materialen"
                    " aan de bodem toe te voegen. Op die manier kunnen verschillende"
                    " vormen van menselijke activiteit gedetecteerd worden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) 12.2.3. Geofysische en geochemische onderzoeksmethoden, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                    " 2) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 3) Renfrew C. &amp; Bahn P. 2000,"
                    " Archaeology: Theories, Methods and Practice, London."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [14],
        "id": 21,
        "labels": [
            {"label": "geofysisch onderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [28, 25, 24, 22, 30],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Geofysisch onderzoek is onderzoek gebaseerd op geofysische"
                    " meettechnieken. Dergelijk onderzoek berust op de contrasten in"
                    " fysische eigenschappen die antropogene structuren, sporen,"
                    " enz..., kunnen vertonen met het omliggende natuurlijke sediment."
                    " Geofysisch onderzoek biedt ook de mogelijkheid om een"
                    " morfologische reconstructie uit te voeren van het natuurlijke"
                    " landschap."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Kwaliteitsnorm Nederlandse Archeologie (KNA - Verklarende"
                    " Woordenlijst) 2) Ervynck A., Degryse P., Vandenabeele P. &amp;"
                    " Verstraeten G. 2009, Natuurwetenschappen en archeologie. Methode"
                    " en interpretatie, Leuven. 3) 12.2.3. Geofysische en geochemische"
                    " onderzoeksmethoden. in: Onderzoeksbalans Onroerend Erfgoed"
                    " Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [63],
        "id": 126,
        "labels": [
            {
                "label": "geografische herinventarisatie",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [35],
        "id": 63,
        "labels": [
            {
                "label": "geografische inventarisatie",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [65, 126],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [63],
        "id": 65,
        "labels": [
            {
                "label": "geografische inventarisatie uit ankerplaatsen",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 25,
        "labels": [
            {"label": "grondradaronderzoek", "language": "nl", "type": "prefLabel"},
            {"label": "GPR", "language": "nl", "type": "altLabel"},
            {"label": "ground penetrating radar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Grondradar maakt gebruik van radiogolven die de bodem worden"
                    " ingestuurd en die door verschillen in densiteit van de bodem"
                    " anders worden gereflecteerd (bv. door de aanwezigheid van"
                    " vloeren, muren, enz.). De diepte van het spoor wordt gemeten door"
                    " het tijdsinterval tussen verzenden van het signaal en de"
                    " ontvangen reflectie. Een GPR-toestel wordt over het oppervlak"
                    " gesleept volgens een rastervormig patroon met vaste meetraaien."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) 12.2.3. Geofysische en geochemische onderzoeksmethoden, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                    " 2) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 3) Renfrew C. &amp; Bahn P. 2000,"
                    " Archaeology: Theories, Methods and Practice, London."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 6,
        "labels": [
            {"label": "historische studie", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [7],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Historische studie is de studie van historische bronnen, zoals"
                    " documenten en historisch kaartmateriaal. Bepaalde relicten kunnen"
                    " in historische bronnen reeds vermeld zijn en op oude kaarten"
                    " weergegeven zijn. Dit geeft interessante bijkomende informatie"
                    " omtrent de vondsten en de bewaringstoestand in die periode."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Barker P. 1993, Techniques of archaeological excavation (third"
                    " edition), London &amp; New York."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [99],
        "id": 106,
        "labels": [{"label": "houtonderzoek", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Bij onderzoek van hout wordt in de eerste plaats bepaald uit welke"
                    " houtsoort een voorwerp of constructie is gemaakt. Het is"
                    " belangrijk na te gaan welke houtsoorten voor welke toepassingen"
                    " werden gebruikt. Het onderzoek van hout kan ook informatie geven"
                    " over hoe het landschap en de vegetatie in het verleden eruit"
                    " zagen. Hout kan ook gebruikt worden voor het dateren van"
                    " archeologische contexten, objecten of constructies."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 2) 9.2.4. Hout en houtskool, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                ),
                "type": "note",
            },
        ],
        "related": [84, 89, 107],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [56],
        "id": 58,
        "labels": [
            {"label": "infraroodfotografie", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Infraroodfotografie maakt gebruik van het infrarood gedeelte van"
                    " het elektromagnetisch spectrum om aspecten die niet zichtbaar"
                    " zijn voor het menselijk oog naar voor te brengen. Infrarood geeft"
                    " bijvoorbeeld de groeistadia van planten weer (gezonde planten"
                    " geven een hoge infrarood reflectie) en spoort waterlopen op"
                    " (water absorbeert infrarood en kent een zeer lage -als zwart"
                    " weergegeven-reflectie). Ook kan men duidelijk onderscheid maken"
                    " tussen droge en natte bodems."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) S.n. 2005, De aarde van op afstand bekeken, in: Nieuwsbrief"
                    " GIS-Vlaanderen (juni 2005, nr. 19). 2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [112],
        "id": 113,
        "labels": [
            {
                "label": "insecten-  en mijtenonderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Het onderzoek naar (resten van) insecten en mijten in"
                    " archeologische context kan informatie verschaffen over"
                    " milieuomstandigheden in het verleden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 35,
        "labels": [{"label": "inventarisatie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [63, 64, 66],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [8],
        "id": 9,
        "labels": [{"label": "kaartstudie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Kaartstudie is het bestuderen van recente kaarten in het kader van"
                    " geografisch, bouwkundig en/of archeologisch onderzoek."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [15],
        "id": 136,
        "labels": [
            {
                "label": "landschappelijk booronderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een landschappelijk booronderzoek houdt het het karteren van de"
                    " geomorfologische/ sedimentaire/ bodemkundige opbouw en"
                    " -eigenschappen van een studiegebied in."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "Onroerend Erfgoed", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [53],
        "id": 54,
        "labels": [
            {"label": "laseraltimetrie", "language": "nl", "type": "prefLabel"},
            {"label": "LIDAR", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Laseraltimetrie of LIDAR (Light Detection and Ranging) is een"
                    " techniek waarbij de hoogte van het aardoppervlak wordt gemeten"
                    " d.m.v. een lasersysteem dat aan boord van een vliegtuig of"
                    " helikopter kan worden gemonteerd."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "AGIV, <a"
                    ' href="https://www.agiv.be/gis/knowhow/?artid=548">https://www.agiv.be/gis/knowhow/?artid=548</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [8],
        "id": 10,
        "labels": [
            {"label": "literatuurstudie", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [53],
        "id": 56,
        "labels": [{"label": "luchtfotografie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [57, 58],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [56],
        "id": 57,
        "labels": [
            {
                "label": "luchtfotografische prospectie",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "archeologische luchtfotografie",
                "language": "nl",
                "type": "altLabel",
            },
            {
                "label": "arch\xe9ologie a\xe9rienne",
                "language": "nl",
                "type": "altLabel",
            },
            {
                "label": "conventionele luchtfotografie",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Luchtfotografische prospectie omvat het maken van luchtfoto's en"
                    " luchtfotografische reeksen die gemaakt zijn met de specifieke"
                    " bedoeling van het opsporen van archeologische relicten."
                    " Luchtfotografie biedt de mogelijkheid om een survey te ondernemen"
                    " van grote oppervlaktes. De meeste luchtfoto's voor archeologisch"
                    " gebruik zijn schuine (i.e. oblieke) luchtfoto's."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [13],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [8],
        "id": 13,
        "labels": [
            {
                "label": "luchtfotografisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Luchtfotografisch onderzoek is het bestuderen van foto's - genomen"
                    " vanuit een luchtvaartuig, zoals een vliegtuig of luchtballon -"
                    " vanuit een archeologisch standpunt. Op deze foto's kunnen"
                    " archeologische sporen zichtbaar worden door o.a. schaduwen"
                    " (shadow marks), verkleuringen in de bodem (soil marks) of in"
                    " gewassen (crop marks). Een zicht vanuit de lucht biedt het ideale"
                    " perspectief voor het bestuderen en begrijpen van het landschap."
                    " Onregelmatigheden aan het oppervlak kunnen bovendien sterker naar"
                    " boven gebracht worden door gebruik te maken van verschillen in"
                    " lichtinval."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) L\u2019Arch\xe9ologie a\xe9rienne dans la France du Nord, <a"
                    ' href="https://www.archeologie-aerienne.culture.gouv.fr/fr/">https://www.archeologie-aerienne.culture.gouv.fr/fr/</a>'
                    " 2) Bourgeois J. &amp; Meganck M. (eds.) 2003, Aerial photography"
                    " and archaeology 2003. A century of information, Archaeological"
                    " Reports Ghent University 4, Gent. 3) Carver M. 1999,"
                    " Fieldarchaeology, in: G. Barker (ed.), Companion Encyclopedia of"
                    " Archaeology, pp. 128-181. 4) Roskams S. 2001, Excavation"
                    " (Cambridge manuals in archaeology), Cambridge."
                ),
                "type": "note",
            },
        ],
        "related": [57],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 28,
        "labels": [
            {
                "label": "magnetometrisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "magnetische prospectie", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Bij magnetometrisch onderzoek wordt het magnetisch veld in de"
                    " bodem gemeten. De belangrijkste verschillen in de magnetische"
                    " eigenschappen van de bodem worden veroorzaakt door de verschillen"
                    " in aantal en aard van ijzermineralen. De methode is dus vooral"
                    " geschikt voor archeologische relicten die verschillen vertonen in"
                    " magnetische eigenschappen met de bodem (bv. metalen voorwerpen)."
                    " Relicten blootgesteld aan hevige verhitting, zoals bijvoorbeeld"
                    " haardplaatsen, zijn ook goed op te sporen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) 12.2.3. Geofysische en geochemische onderzoeksmethoden, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                    " 2) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 3) Renfrew C. &amp; Bahn P. 2000,"
                    " Archaeology: Theories, Methods and Practice, London."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [112],
        "id": 114,
        "labels": [
            {"label": "malacologisch onderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Malacologisch onderzoek is het onderzoek naar mollusken"
                    " (weekdieren). Dergelijk onderzoek omvat de taxonomie, ecologie en"
                    " evolutie van mollusken. Mollusken zijn goede milieu-indicatoren"
                    " en kunnen informatie verschaffen over het paleomilieu en"
                    " paleoklimaat waar ze in archeologische opgravingen werden"
                    " teruggevonden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [39],
        "id": 79,
        "labels": [{"label": "materiaalstudie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Materiaalstudie omvat het beschrijven, bestuderen, determineren en"
                    " tekenen/fotograferen van materiaal gevonden bij archeologisch"
                    " onderzoek."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 30,
        "labels": [{"label": "metaaldetectie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Metaaldetectie is een manier om metalen voorwerpen op te sporen."
                    " Het principe van een metaaldetector berust op het natuurkundig"
                    " principe van elektromagnetische inductie en het ontstaan van"
                    " wervelstromen. De bodem wordt door middel van een puls met een"
                    " metaaldetector een elektromagnetisch veld opgelegd. De"
                    " aanwezigheid van metaal kan worden vastgesteld omdat het langer"
                    " en sterker magnetisch blijft dan de bodem zelf en ander in de"
                    " bodem aanwezig materiaal. Door verschillen in elektromagnetische"
                    " resonantiefrequentie kunnen metaalsoorten van elkaar worden"
                    " onderscheiden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Groenewoudt B.J. 1994, Prospectie, waardering en selectie van"
                    " archeologische vindplaatsen: een beleidsgerichte verkenning van"
                    " middelen en mogelijkheden, Nederlandse Archeologische Rapporten"
                    " 17, Amersfoort. 2) Renfrew C. &amp; Bahn P. 2000, Archaeology:"
                    " Theories, Methods and Practice, London. 3) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 131,
        "labels": [
            {
                "label": "micromorfologisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Micromorfologisch onderzoek of bodemmicromorfologie betreft"
                    " gedetailleerd onderzoek van bodemmateriaal op microscopisch"
                    " niveau. Slijpplaten van bodemmonsters worden microscopisch"
                    " onderzocht om antwoord te geven op vragen met betrekking tot de"
                    " samenstelling en genese van (archeologische) afzettingen."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "Onroerend Erfgoed", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 31,
        "labels": [{"label": "monitoring", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [117],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Monitoring is het meten van de fysieke conditie van een monument"
                    " op bepaalde, vooraf vastgestelde aspecten met daartoe"
                    " ge\xebigende middelen en gedurende een afgesproken periode, met"
                    " als doel inzicht te verwerven in het fysieke degradatieproces van"
                    " archeologische monumenten en de effectiviteit van de getroffen"
                    " maatregelen daartegen. Monitoring is wetenschappelijk onderzoek"
                    " in het kader van de archeologische monumentenzorg."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Kwaliteitsnorm Nederlandse Archeologie (KNA - Verklarende"
                    " Woordenlijst) 2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [14],
        "id": 32,
        "labels": [
            {"label": "muurwerkarcheologie", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Muurwerkarcheologie is het bestuderen van opstaande muren vanuit"
                    " een archeologisch standpunt."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "Voorlopige SN", "type": "historyNote"},
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [36],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [39],
        "id": 80,
        "labels": [
            {
                "label": "natuurwetenschappelijk onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [81, 82, 131, 132],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 48,
        "labels": [
            {
                "label": "niet-systematische veldprospectie",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "niet-systematische veldkartering",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Bij niet-systematische veldprospectie wordt er over elk deel van"
                    " het gebied (bv. elk geploegd veld, zonder in raaien te lopen)"
                    " gelopen en wordt de aanwezigheid van archaeologica geregistreerd"
                    " of worden de archaeologica ingezameld. De resultaten van"
                    " dergelijke kartering zijn zeer subjectief aangezien men"
                    " automatisch geneigd is zich te concentreren op archeologisch"
                    " schijnbaar rijkere zones."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Renfrew C. &amp; Bahn P. 2000, Archaeology: Theories, Methods and"
                    " Practice, London."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [38],
        "id": 71,
        "labels": [{"label": "noodopgravingen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [70],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een noodopgraving is een opgraving veroorzaakt door de bedreiging"
                    " van een site door uitvoering van werken met als doel het zo goed"
                    " mogelijk documenteren van aanwezige informatie in een beperkte"
                    " tijdspanne."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Kwaliteitsnorm Nederlandse Archeologie (KNA - Verklarende"
                    " Woordenlijst) 2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [34],
        "id": 62,
        "labels": [
            {"label": "oeuvrestudie architect", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [109],
        "id": 111,
        "labels": [
            {
                "label": "onderzoek van gewervelde diersoorten",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Onderzoek naar resten van gewervelden. De groep van de gewervelde"
                    " diersoorten omvat vissen, amfibie\xebn, reptielen, vogels en"
                    " zoogdieren."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [109],
        "id": 112,
        "labels": [
            {
                "label": "onderzoek van ongewervelde diersoorten",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [113, 114],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Onderzoek naar resten van ongewervelden. De groep van de"
                    " ongewervelden omvat onder andere insecten (zes poten), spinnen en"
                    " mijten (acht poten), schaaldieren, schelpdieren, wormen,"
                    " enz\u2026"
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [8],
        "id": 12,
        "labels": [
            {
                "label": "onderzoek van satellietbeelden",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Het onderzoek van satellietbeelden is nuttig voor het opsporen van"
                    " bestaande archeologische sites die dankzij hoogteverschillen en"
                    " vegetatie zichtbaar worden. Een voordeel van satellieten is dat"
                    " ze opnames kunnen maken van delen in het elektromagnetisch"
                    " spectrum die niet zichtbaar zijn met het menselijk oog, waardoor"
                    " bepaalde anomalie\xebn beter zichtbaar worden. Niet alleen"
                    " bestaande sites kunnen opgespoord worden, maar ook kan men aan de"
                    " hand van allerlei omgevingsfactoren (hoogteligging, vegetatie,"
                    " bodemeigenschappen) bepalen of een bepaalde zone kans maakt om"
                    " archeologische sporen te herbergen (hoewel men deze techniek met"
                    " enige voorzichtigheid moet benaderen)."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Dutch Expertise Centre for Archaeological Remote Sensing, <a"
                    ' href="https://www.decars.nl/index.php?option=com_content&amp;task=view&amp;id=32&amp;Itemid=63">https://www.decars.nl/index.php?option=com_content&amp;task=view&amp;id=32&amp;Itemid=63</a>'
                    " 2) Roskams S. 2001, Excavation (Cambridge manuals in"
                    " archaeology), Cambridge."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "id": 67,
        "labels": [
            {"label": "opgravingen naar methode", "language": "nl", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [68, 69],
        "notes": [],
        "superordinates": [38],
        "type": "collection",
    },
    {
        "id": 70,
        "labels": [
            {
                "label": "opgravingen naar motivatie",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [71, 73, 74],
        "notes": [],
        "superordinates": [38],
        "type": "collection",
    },
    {
        "id": 75,
        "labels": [
            {
                "label": "opgravingen naar oppervlaktedekking",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [76, 77],
        "notes": [],
        "superordinates": [38],
        "type": "collection",
    },
    {
        "broader": [38],
        "id": 73,
        "labels": [
            {
                "label": "opgravingen vanuit wetenschappelijke vraagstelling",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [70],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een opgraving vanuit wetenschappelijke vraagstelling is een"
                    " opgraving die wordt gepland en uitgevoerd in functie van een"
                    " specifieke onderzoeksvraag en dus in tegenstelling tot een"
                    " noodopgraving geen directe bedreiging van het site als motivatie"
                    " heeft."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [83],
        "id": 91,
        "labels": [
            {
                "label": "optisch gestimuleerde luminescentiedatering",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "OSL", "language": "nl", "type": "altLabel"},
            {
                "label": "optically stimulated luminescence",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Optisch gestimuleerde luminescentie maakt gebruik van laser- of"
                    " infraroodlicht om de opgeslagen stralingsenergie in de mineralen"
                    " vrij te krijgen. Naarmate de belichting langer duurt, zal de"
                    " intensiteit van het licht dat vrijkomt geleidelijk afnemen. OSL"
                    " wordt vooral gebruikt voor het dateren van sedimenten bestaande"
                    " uit kwarts en veldspaat."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [15],
        "id": 16,
        "labels": [
            {
                "label": "paleolandschappelijk booronderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [99],
        "id": 101,
        "labels": [
            {"label": "palynologisch onderzoek", "language": "nl", "type": "prefLabel"},
            {"label": "pollenanalyse", "language": "nl", "type": "altLabel"},
            {"label": "stuifmeelonderzoek", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Palynologisch onderzoek omvat de analyse van pollen en sporen die"
                    " in een natuurlijke of antropogene, sedimentaire context bewaard"
                    " zijn gebleven. De meeste planten produceren zeer veel pollen of"
                    " sporen die over een grote afstand kunnen verspreid worden."
                    " Hierdoor kunnen ze informatie verschaffen over de vegetatie in"
                    " het verleden van een groot gebied rond de bemonsteringsplaats."
                    " Naast de natuurlijke vegetatie kan palynologisch onderzoek ook"
                    " informatie opleveren over de aanwezigheid van bepaalde"
                    " landbouwgewassen op en rond een site. In zeer specifieke"
                    " gevallen, zoals bij een beerputonderzoek, kan het informatie"
                    " geven over dieetgewoontes in het verleden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 2) 9.2.2. Pollen en sporen, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 39,
        "labels": [
            {
                "label": "post-excavation onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [78, 79, 80],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [38],
        "id": 74,
        "labels": [
            {"label": "preventieve opgravingen", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [70],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een preventieve opgraving is een opgraving die wordt gepland in"
                    " het kader van een bouwactiviteit en dus ook reeds bij de"
                    " bouwvergunning wordt ingecalculeerd."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [83],
        "id": 84,
        "labels": [
            {"label": "radiokoolstofdatering", "language": "nl", "type": "prefLabel"},
            {"label": "C14-datering", "language": "nl", "type": "altLabel"},
            {"label": "14C-datering", "language": "nl", "type": "altLabel"},
            {
                "label": "radioactieve koolstofdatering",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Radiokoolstofdatering of 14C-datering is een dateringsmethode voor"
                    " archeologische objecten en contexten die organisch materiaal"
                    " bevatten. In de atmosfeer is het gehalte aan 14C constant. Dit"
                    " betekent dat ook alle levende organismen een constant gehalte aan"
                    " 14C in hun cellen hebben. Wanneer het levend wezen sterft, stopt"
                    " de uitwissling echter en begint het onstabiele 14C-isotoop te"
                    " vervallen. Dit vormt het basisprincipe van de"
                    " radiokoolstofdatering. Vermits het radioactief verval volgens een"
                    " gekend tempo verloopt, kan men aan de hand van de meting van het"
                    " resterend aandeel 14C een schatting maken van de tijd die"
                    " verstreken is sinds de dood van het organisme. Dateringen kunnen"
                    " uitgevoerd worden van objecten die tot 50.000 jaar oud zijn. De"
                    " datering zelf gebeurt door het verbranden van stoffelijke resten."
                    " Hierbij komt CO2 vrij en hieraan wordt de radioactiviteit"
                    " gemeten."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [106, 107],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 3,
        "labels": [{"label": "restauratie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [117],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Restauratie is het geheel van handelingen aan een beschadigd of"
                    " gedeeltelijk verloren gegaan bouwkundig of archeologisch relict"
                    " of object met het doel deze terug te brengen in een vooraf"
                    " gedefinieerde toestand."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": "1) International Council of Museums 2) VIOE",
                "type": "note",
            },
        ],
        "related": [4],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [38],
        "id": 76,
        "labels": [
            {"label": "sleuvenonderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [75],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een sleuvenonderzoek is een opgraving waarbij slechts een deel van"
                    " het op te graven terrein wordt blootgelegd aan de hand van enkele"
                    " strategisch geplaatste sleuven. Dergelijke opgravingen staan in"
                    " tegenstelling tot vlakdekkende opgravingen waar het volledige te"
                    " onderzoeken areaal wordt blootgelegd."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
            {
                "language": "nl",
                "note": (
                    "Een sleuvenonderzoek mag niet verward worden met proefonderzoek"
                    " (voorkeursterm 'prospectie met ingreep in de bodem')."
                    " Proef(sleuven)onderzoek is bedoeld voor het opsporen en evalueren"
                    " van sites, terwijl een sleuvenonderzoek een eigenlijke opgraving"
                    " van een gekende site is."
                ),
                "type": "scopeNote",
            },
        ],
        "related": [41],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [38],
        "id": 68,
        "labels": [
            {
                "label": "stratigrafische opgravingen",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [67],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een stratigrafische opgraving is een opgraving waarbij de"
                    " gelaagdheid van de bodem wordt gevolgd en stratigrafische laag"
                    " voor stratigrafische laag wordt weggegraven, ongeacht haar"
                    " verloop. Dit in tegenstelling tot een vlakopgraving waarbij"
                    " meerdere periodes binnen hetzelfde vlak worden onderzocht."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) VIOE 2) De Meulemeester J. &amp; Ervynck A. 1990, Archeologie:"
                    " meer dan opgraven, in: Vlaanderen 231, jg. 39 mei-juni 1990"
                    " (Vlaamse archeologie : opgravingen in binnen- en buitenland), pp."
                    " 155-160."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 121,
        "labels": [{"label": "synchronisaties", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [118],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een synchronisatie in het kader van erfgoedonderzoek is het"
                    " aanvullen van gegevens op basis van informatie uit een  andere"
                    " databank."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "agentschap Onroerend Erfgoed", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 49,
        "labels": [
            {
                "label": "systematische veldprospectie",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "systematische veldkartering",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [50],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Systematische veldprospectie gebeurt voornamelijk in"
                    " transecten/raaien op 5 tot 500 meter uit elkaar of in kwadranten."
                    " Er wordt gestreefd naar een zo representatief mogelijke aanpak."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Carver M. 1999, Fieldarchaeology, in: G. Barker (ed.),"
                    " Companion Encyclopedia of Archaeology, pp. 128-181. 2) Renfrew C."
                    " &amp; Bahn P. 2000, Archaeology: Theories, Methods and Practice,"
                    " London."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 53,
        "labels": [{"label": "teledetectie", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [54, 56],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Teledetectie is een techniek om informatie te verkrijgen en vast"
                    " te leggen van objecten en verschijnselen door waarneming op"
                    " afstand (bijvoorbeeld vanuit een vliegtuig of satelliet), waarbij"
                    " zowel fotografische als niet-fotografische technieken (radar,"
                    " infrarood) worden toegepast."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Groenewoudt B.J. 1994, Prospectie, waardering en selectie van"
                    " archeologische vindplaatsen: een beleidsgerichte verkenning van"
                    " middelen en mogelijkheden, Nederlandse Archeologische Rapporten"
                    " 17, Amersfoort. 2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 14,
        "labels": [
            {"label": "terreinonderzoek", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [15, 18, 21, 32, 40, 52],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [35],
        "id": 64,
        "labels": [
            {
                "label": "thematische inventarisatie",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [83],
        "id": 94,
        "labels": [
            {
                "label": "thermoluminescentiedatering",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "TL", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Thermoliminescentie is een zwakke uitstoot van licht veroorzaakt"
                    " door het verhitten van gemalen archeologisch aardewerk. Deze"
                    " uitstoot komt van mineralen in het aardewerk die blootgesteld"
                    " zijn geweest aan straling van radioactieve sporenelementen uit"
                    " het aardewerk of uit de bodem waarin de vondst begraven zat. Hoe"
                    " ouder, hoe meer straling. Het meten van de intensiteit kan als"
                    " dateringmethode gebruikt worden. Deze methode is vaak"
                    " onnauwkeuriger en omslachtiger dan de C14-datering."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009,"
                    " Natuurwetenschappen en archeologie. Methode en interpretatie,"
                    " Leuven."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2,
        "labels": [{"label": "toevalsvondsten", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [116],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een toevalsvondst is een onverwachte vondst van roerende of"
                    " onroerende archaeologica die gedaan wordt aan de oppervlakte,"
                    " onder de grond of onder water en die niet verbonden is aan een"
                    " vergunde opgraving of prospectie."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [6],
        "id": 7,
        "labels": [
            {"label": "toponymische studie", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Toponymische studie is de wetenschappelijke studie van"
                    " plaatsnamen. Hierbij gaat men uit van de oudste versie van de"
                    " naam. Door het bestuderen van plaatsnamen krijgt men inzicht in"
                    " het toenmalige landschap, de geschiedenis van de plaats, de aard"
                    " van de nederzetting, enz... Toponiemen zijn ontstaan doordat de"
                    " mens de behoefte heeft het landschap waarin hij zich bevindt te"
                    " beschrijven. Ze zijn in de eerste plaats bedoeld voor"
                    " ori\xebntatie in het landschap. Verder verwijzen ze vaak naar"
                    " bijzondere/uitzonderlijke aspecten in dit landschap. Een toponiem"
                    " geeft ook een idee van de datering van de plaatsnaam. Tenslotte"
                    " geeft het toponiem ook informatie over taal en evolutie van taal."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "ter Laak J.C. 2005, De taal van het landschap. Pilotproject"
                    " toponiemen in de Berkelstreek, in: Rapportage Archeologische"
                    " Monumentenzorg 123, Amersfoort."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 34,
        "labels": [
            {
                "label": "typologisch-thematisch onderzoek",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [62],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 124,
        "labels": [{"label": "vaststellingen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [122],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [38],
        "id": 77,
        "labels": [
            {"label": "vlakdekkende opgravingen", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [75],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een vlakdekkende opgraving (open area excavation) is een opgraving"
                    " waarbij het volledige op te graven vlak wordt blootgelegd."
                    " Dergelijke opgravingen staan in tegenstelling tot"
                    " sleuvenopgravingen, waar gekozen wordt om een kleiner areaal"
                    " bloot te leggen aan de hand van enkele strategisch geplaatste"
                    " sleuven. Een vlakdekkende opgraving mag niet verward worden met"
                    " een vlakopgraving (opgraving aan de hand van min of meer"
                    " waterpasse vlakken waarbij sporen uit meerdere periodes zichtbaar"
                    " worden)."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) VIOE 2) Carver M. 1999, Fieldarchaeology, in: G. Barker (ed.),"
                    " Companion Encyclopedia of Archaeology, pp. 128-181."
                ),
                "type": "note",
            },
            {
                "language": "nl",
                "note": (
                    "Niet te verwarren met 'vlakopgravingen' waarbij min of meer"
                    " waterpasse vlakken worden opgegraven, maar daarom niet"
                    " vlakdekkend zijn"
                ),
                "type": "scopeNote",
            },
        ],
        "related": [69],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [38],
        "id": 69,
        "labels": [{"label": "vlakopgravingen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [67],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een vlakopgraving is een opgraving waarbij min of meer waterpasse"
                    " vlakken worden blootgelegd en sporen uit meerdere periodes worden"
                    " onderzocht en gecoupeerd."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [77],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [99],
        "id": 104,
        "labels": [
            {
                "label": "zaden- en vruchtenonderzoek",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "diasporenonderzoek", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Zaden- en vruchtenonderzoek is volledig gestoeld op de uitwendige"
                    " morfologische kenmerken van de zaden/vruchten. Wanneer men een"
                    " monster uit een archeologische context analyseert, wordt op een"
                    " kwantitatieve manier een soortenlijst per monster opgesteld."
                    " Zaden- en vruchtenonderzoek kan leiden tot een reconstructie van"
                    " de voedsel - en landbouweconomie van een vroegere mensengroep."
                    " Ook het ritueel gebruik van planten (met bijvoorbeeld een monster"
                    " uit een grafkuil) kan met dergelijk onderzoek worden nagegaan."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G."
                    " 2009, Natuurwetenschappen en archeologie. Methode en"
                    " interpretatie, Leuven. 2) 9.2.3. Zaden en vruchten, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
]
