BLUEBIRDSDATA = [
        {
            'id': 'https://id.bluebirds.org/bird', 
            'uri': 'https://id.bluebirds.org/bird', 
            'type': 'concept', 
            'labels': [{'label': 'Bird', 'type': 'prefLabel', 'language': 'en'}, {'label': 'Vogel', 'type': 'prefLabel', 'language': 'nl'}], 
            'notes': [], 
            'sources': [], 
            'narrower': ['parrot', '579A439C-1A7A-476A-92C3-8A74ABD6B3DB'], 
            'broader': [], 
            'related': [], 
            'member_of': [], 
            'subordinate_arrays': [], 
            'matches': {'close': [], 'exact': [], 'related': [], 'broad': [], 'narrow': []}
        }, 
        {

            'id': 'parrot',
            'uri': 'https://id.bluebirds.org/parrot',
            'type': 'concept',
            'labels': [{'label': 'Parrot', 'type': 'prefLabel', 'language': 'en'}, {'label': 'Papegaai', 'type': 'prefLabel', 'language': 'nl'}],
            'notes': [],
            'sources': [],
            'narrower': ['norwegianblue'],
            'broader': [],
            'related': [],
            'member_of': [],
            'subordinate_arrays': [], 'matches': {'close': [], 'exact': [], 'related': [], 'broad': [], 'narrow': []}
        },
        {
            'id': 'norwegianblue',
            'uri': 'https://id.bluebirds.org/norwegianblue',
            'type': 'concept',
            'labels': [{'label': 'Norwegian Blue', 'type': 'prefLabel', 'language': 'en'}, {'label': 'Noorse Blauwe', 'type': 'prefLabel', 'language': 'nl'}],
            'notes': [],
            'sources': [],
            'narrower': [],
            'broader': ['parrot'],
            'related': [],
            'member_of': [],
            'subordinate_arrays': [],
            'matches': {'close': [], 'exact': [], 'related': ['https://id.slugs.org/slug'], 'broad': [], 'narrow': []}
        },
        {
            'id': '579A439C-1A7A-476A-92C3-8A74ABD6B3DB',
            'uri': 'https://id.bluebirds.org/579A439C-1A7A-476A-92C3-8A74ABD6B3DB',
            'type': 'concept',
            'labels': [{'label': 'Heron', 'type': 'prefLabel', 'language': 'en'}, {'label': 'Héron', 'type': 'prefLabel', 'language': 'fr'}, {'label': 'Reiger', 'type': 'prefLabel', 'language': 'nl'}],
            'notes': [],
            'sources': [],
            'narrower': ['blauwereiger'],
            'broader': [],
            'related': [],
            'member_of': [],
            'subordinate_arrays': [],
            'matches': {'close': [], 'exact': [], 'related': [], 'broad': [], 'narrow': []}
        }, 
        {
            'id': 'blauwereiger',
            'uri': 'https://id.bluebirds.org/blauwereiger',
            'type': 'concept',
            'labels': [{'label': 'Grey heron', 'type': 'prefLabel', 'language': 'en'}, {'label': 'Héron cendré', 'type': 'prefLabel', 'language': 'fr'}, {'label': 'Blauwe reiger', 'type': 'prefLabel', 'language': 'nl'}, {'label': 'Ardea cinerea', 'type': 'prefLabel', 'language': 'la'}],
            'notes': [],
            'sources': [],
            'narrower': [],
            'broader': [],
            'related': [],
            'member_of': [],
            'subordinate_arrays': [],
            'matches': {'close': [], 'exact': [], 'related': [], 'broad': [], 'narrow': []}
        }
]
