<div class="large-6 columns ptext">
  {#		<h2>{% trans %}welcome_to{% endtrans %}</h2>#}
	<p>{% trans admin_route = request.route_path('admin') %}atramhasis_expl{% endtrans %}</p>
	<p><strong>{% trans %}more_information{% endtrans %}</strong></p>
	<ul class="no_bullet">
		<li class="cube"><a href="https://github.com/OnroerendErfgoed/atramhasis/discussions">{% trans %}discussion_forum{% endtrans %}</a></li>
		<li class="cube"><a href="https://atramhasis.readthedocs.io">{% trans %}online_documentation{% endtrans %}</a></li>
		<li class="cube"><a href="https://github.com/OnroerendErfgoed/atramhasis">{% trans %}issue_tracker{% endtrans %}</a></li>
	</ul>
</div>
