<div class="large-8 columns">
  <h2>
    Welcome to Atramhasis!
  </h2>
  <h4>Atramhasis is an open-source, web-based <a href='http://www.w3.org/2004/02/skos/'>SKOS</a> editor. </h4>
  <h4>You can use this webapplication to browse, edit and add SKOS vocabularies, thesauri, authority files, word lists, ... through the amdin interface.</h4>
</div>
