<div class="slidemenu-container slidemenu-close" data-dojo-attach-point="menuContainer" data-dojo-attach-event="onClick: _slideOpen">
  <div class="slidemenu-inner">
    <div data-dojo-attach-point="menuNode"></div>
  </div>
</div>
