<div>

  <header>
    <nav class="top-bar" data-topbar role="navigation">
      <ul class="title-area">
        <li class="name">
          <a href="/"><img src="${staticAppPath}img/atramlogo.png" class="left logo-small">
            <h1 class="left logo-small-text">Atramhasis</h1>
          </a>
        </li>
      </ul>
      <div class="top-bar-section">
        <!-- Right Nav Section -->
        <ul class="right">
          <li class="divider"></li>
          <li>
            <a class="button tiny menu-button" data-dojo-attach-event="onClick: _toggleMenu"><i class="fa fa-bars"></i>MENU</a>
          </li>
        </ul>
      </div>
    </nav>
  </header>

  <div class="app-content-container" data-dojo-attach-point="appContentContainer">

    <div data-dojo-attach-point="conceptContainerNode"></div>

    <div class="app-menu">
      <div data-dojo-attach-point="menuContainerNode">
      </div>
      <div class="slidemenu-overlay slideoverlay-close" data-dojo-attach-point="menuOverlayContainer" data-dojo-attach-event="onClick: _closeMenu"></div>
    </div>
  </div>

  <footer>
    © Copyright 2014-2023 <a href="https://www.onroerenderfgoed.be/">Flanders Heritage Agency</a>
    <div class="right">nl | fr | en</div>
  </footer>

</div>
