{% extends 'layout.jinja2' %}

{% block html_title %}{% trans %}500_title{% endtrans %}{% endblock %}

{% block content %}
  <div class="large-12 columns">
    <div class="row">
      <div class="large-12 columns panel">
        <h1 class="panel-header">{% trans %}500_error{% endtrans %}</h1>
        <h5 style="font-size: 20px;">
          {% trans %}500_explanation{% endtrans %}
        </h5>
      </div>
    </div>
  </div>
{% endblock %}

{% block subfooter %}
{% endblock %}
