<div data-dojo-attach-point="conceptDetailNode">
  <div class="large-12 columns" style="margin-top: 20px; padding-bottom: 20px;">
    <div class="large-7 columns">
      <h1 data-dojo-attach-point="conceptTitleViewNode"></h1>
      <span class="concept-title-info" data-dojo-attach-point="idViewNode"></span>
      <span class="concept-title-info" data-dojo-attach-point="typeViewNode"></span>
      <span class="concept-title-info" data-dojo-attach-point="uriViewNode"></span>
    </div>
    <div class="large-5 columns">
      <a href="#" class="button tiny right" target="_blank" data-dojo-attach-point="viewConceptNode">VIEW</a>
      <a href="#" class="button tiny right" style="margin-right: 10px;" data-dojo-attach-event="onClick: _deleteConcept">DELETE</a>
      <a href="#" class="button tiny right" style="margin-right: 10px;" data-dojo-attach-event="onClick: _openEditDialog">EDIT</a>
      <button href="#" class="button tiny right" style="margin-right: 10px;" data-dojo-attach-event="onClick: _openMergeDialog"
         data-dojo-attach-point="mergeButton">MERGE</button>
    </div>
  </div>
  <hr class="concept-hr">
  <div class="large-12 columns label-relation-block">
    <div class="large-6 columns">
      <h4 class="no-top-padding">Labels</h4>
      <dl class="dllist">
        <dt>Preferred labels</dt><dd data-dojo-attach-point="preferredLabelsNode"></dd>
        <dt>Alternate labels</dt><dd data-dojo-attach-point="alternateLabelsNode"></dd>
        <dt>Hidden labels</dt><dd data-dojo-attach-point="hiddenLabelsNode"></dd>
        <dt>Sort labels</dt><dd data-dojo-attach-point="sortLabelsNode"></dd>
      </dl>
    </div>
    <div class="large-6 columns">
      <h4 class="no-top-padding">Relations</h4>
      <dl class="dllist" data-dojo-attach-point="relationsListNode">
      </dl>
      <h4 class="no-top-padding">Matches</h4>
      <dl class="dllist" data-dojo-attach-point="matchesListNode">
      </dl>
    </div>
  </div>
  <hr class="concept-hr">
  <div class="large-12 columns">
    <div class="large-12 columns">
      <ul class="scopeNote" data-dojo-attach-point="scopeNoteNode">
        <h3>notes</h3>
      </ul>
    </div>
    <div class="large-12 columns">
      <ul class="scopeNote" data-dojo-attach-point="sourcesNode">
        <h3>sources</h3>
      </ul>
    </div>
  </div>
</div>