{% from "macros.jinja2" import popular_concepts %}

<div class="row">
  <div class="large-4 columns">
    <div class="subfooter-page">
      <h5>{% trans %}popular_category{% endtrans %}</h5>
      {{ popular_concepts(request, request.matchdict['scheme_id'], 4) }}
    </div>
  </div>
  <div class="large-4 columns">
    <div class="subfooter-page">
      <h5>{% trans %}recently_viewed{% endtrans %}</h5>
      <ul class="no_bullet">
        {% for c in request.session['last_visited']|reverse() %}
          <li class="cube"><a href="{{ c.url }}">{{ c.label|capitalize() }}</a></li>
        {% endfor %}
      </ul>
    </div>
  </div>
  <div class="large-4 columns">
    <div class="subfooter-page">
      <h5>{% trans %}select_scheme{% endtrans %}</h5>
      <ul class="no_bullet">
        {% for c in conceptschemes %}
          <li class="cube"><a href="{{ request.route_path('skosprovider.conceptscheme', scheme_id=c.id) }}">{{ c.conceptscheme.label(request.locale_name).label }}</a></li>
        {% endfor %}
      </ul>
    </div>
  </div>
</div>