SPECIESDATA = [
    {
        "broader": [],
        "id": 2004,
        "labels": [
            {"label": "Abies", "language": "nl", "type": "prefLabel"},
            {"label": "zilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            495,
            496,
            497,
            498,
            499,
            500,
            501,
            502,
            503,
            504,
            505,
            506,
            507,
            508,
            509,
            510,
            511,
            512,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 495,
        "labels": [
            {"label": "Abies alba", "language": "nl", "type": "prefLabel"},
            {"label": "Gewone zilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 496,
        "labels": [
            {"label": "Abies amabilis", "language": "nl", "type": "prefLabel"},
            {"label": "Pacifische zilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 497,
        "labels": [
            {"label": "Abies balsamea", "language": "nl", "type": "prefLabel"},
            {"label": "balsemzilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 498,
        "labels": [
            {"label": "Abies cephalonica", "language": "nl", "type": "prefLabel"},
            {"label": "Griekse zilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 499,
        "labels": [{"label": "Abies cilicica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 500,
        "labels": [
            {"label": "Abies concolor", "language": "nl", "type": "prefLabel"},
            {"label": "Coloradozilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [370],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [500],
        "id": 370,
        "labels": [
            {
                "label": "Abies concolor var. Lowiana",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 501,
        "labels": [
            {"label": "Abies firma", "language": "nl", "type": "prefLabel"},
            {"label": "Momizilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 502,
        "labels": [
            {"label": "Abies grandis", "language": "nl", "type": "prefLabel"},
            {"label": "reuzenzilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 503,
        "labels": [{"label": "Abies homolepis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 504,
        "labels": [
            {"label": "Abies koreana", "language": "nl", "type": "prefLabel"},
            {"label": "Koreaanse zilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 505,
        "labels": [
            {"label": "Abies lasiocarpa", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 506,
        "labels": [{"label": "Abies magnifica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 507,
        "labels": [
            {"label": "Abies nordmanniana", "language": "nl", "type": "prefLabel"},
            {"label": "Kaukasische zilverspar", "language": "nl", "type": "altLabel"},
            {"label": "Nordmannspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 508,
        "labels": [
            {"label": "Abies pinsapo", "language": "nl", "type": "prefLabel"},
            {"label": "Spaanse zilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 509,
        "labels": [
            {"label": "Abies procera", "language": "nl", "type": "prefLabel"},
            {"label": "edelspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 510,
        "labels": [
            {"label": "Abies sachalinensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 511,
        "labels": [
            {"label": "Abies spectabilis", "language": "nl", "type": "prefLabel"},
            {"label": "Himalayazilverspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2004],
        "id": 512,
        "labels": [{"label": "Abies veitchii", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1,
        "labels": [
            {"label": "Acer", "language": "la", "type": "prefLabel"},
            {"label": "esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            2,
            3,
            4,
            5,
            6,
            7,
            8,
            9,
            10,
            11,
            12,
            13,
            14,
            15,
            16,
            17,
            18,
            19,
            20,
            21,
            22,
            23,
            24,
            25,
            26,
            27,
            28,
            29,
            30,
            31,
            371,
            374,
            32,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 371,
        "labels": [
            {"label": "Acer buergerianum", "language": "nl", "type": "prefLabel"},
            {"label": "drietandesdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 2,
        "labels": [
            {"label": "Acer campestre", "language": "nl", "type": "prefLabel"},
            {"label": "veldesdoorn", "language": "nl", "type": "altLabel"},
            {"label": "Spaanse aak", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 3,
        "labels": [
            {"label": "Acer capillipes", "language": "nl", "type": "prefLabel"},
            {"label": "rode slange-esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 4,
        "labels": [
            {"label": "Acer cappadocium", "language": "nl", "type": "prefLabel"},
            {"label": "Cappadocische esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [372],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [4],
        "id": 372,
        "labels": [
            {
                "label": "Acer cappadocium 'Aureum'",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "geelbladige Cappadocische esdoorn",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 5,
        "labels": [
            {"label": "Acer carpinifolium", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 6,
        "labels": [{"label": "Acer circinatum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 7,
        "labels": [
            {"label": "Acer cissifolium", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 8,
        "labels": [{"label": "Acer davidii", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 9,
        "labels": [{"label": "Acer ginnala", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 10,
        "labels": [
            {"label": "Acer griseum", "language": "nl", "type": "prefLabel"},
            {"label": "papieresdoorn", "language": "nl", "type": "altLabel"},
            {"label": "papierschorsesdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 11,
        "labels": [
            {"label": "Acer grosseri", "language": "nl", "type": "prefLabel"},
            {"label": "Chinese slange-esdoorn", "language": "nl", "type": "altLabel"},
            {
                "label": "Acer davidii subsp. grosseri",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 12,
        "labels": [
            {"label": "Acer heldreichii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 13,
        "labels": [
            {"label": "Acer japonicum", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse rondbladesdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 14,
        "labels": [{"label": "Acer lobelii", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 15,
        "labels": [
            {"label": "Acer macrophyllum", "language": "nl", "type": "prefLabel"},
            {"label": "grootbladesdoorn", "language": "nl", "type": "altLabel"},
            {"label": "grootbladige esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 16,
        "labels": [
            {"label": "Acer maximowiczianum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 17,
        "labels": [{"label": "Acer mono", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 18,
        "labels": [
            {"label": "Acer monspessulanum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 19,
        "labels": [
            {"label": "Acer negundo", "language": "nl", "type": "prefLabel"},
            {"label": "vederesdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [373, 2252],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [19],
        "id": 373,
        "labels": [
            {"label": "Acer negundo 'Auratum'", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Vederesdoorn met geel blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [19],
        "id": 2252,
        "labels": [
            {
                "label": "Acer negundo 'Aureomarginatum'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Een Acer negundo 'Aureomarginatum' is een vederesdoorn met"
                    " geelgerand blad."
                ),
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 374,
        "labels": [
            {
                "label": "Acer negundo var. Violaceum'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Vederesdoorn met blauw berijpte twijgen",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 20,
        "labels": [
            {"label": "Acer opalus", "language": "nl", "type": "prefLabel"},
            {"label": "Italiaanse esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 21,
        "labels": [
            {"label": "Acer palmatum", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse esdoorn", "language": "nl", "type": "altLabel"},
            {"label": "Japanse vingeresdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [376, 377, 378, 375],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 376,
        "labels": [
            {
                "label": "Acer palmatum 'Atropurpureum'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Japanse esdoorn met donkerbruin blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 377,
        "labels": [
            {
                "label": "Acer palmatum 'Matsumurae'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 378,
        "labels": [
            {
                "label": "Acer palmatum 'Osakazuki'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 375,
        "labels": [
            {
                "label": "Acer palmatum var. Amoenum",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Japanse esdoornvari\xebteit met diep ingesneden en vrij groot"
                    " blad."
                ),
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 22,
        "labels": [
            {"label": "Acer pensylvanicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 23,
        "labels": [
            {"label": "Acer platanoides", "language": "nl", "type": "prefLabel"},
            {"label": "Noorse esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [379, 380, 381, 382],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [23],
        "id": 379,
        "labels": [
            {
                "label": "Acer platanoides 'Cucullatum'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Noorse esdoorn met bolstaand blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [23],
        "id": 380,
        "labels": [
            {
                "label": "Acer platanoides 'Drummondii'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Noorse esdoorn met geelgerand blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [23],
        "id": 381,
        "labels": [
            {
                "label": "Acer platanoides 'Faassen's Black'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Noorse esdoorn met donkerbruin blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [23],
        "id": 382,
        "labels": [
            {
                "label": "Acer platanoides 'Schwedleri'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Noorse esdoorn met bruinrood blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 24,
        "labels": [
            {"label": "Acer pseudoplatanus", "language": "nl", "type": "prefLabel"},
            {"label": "gewone esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [383, 384, 385],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [24],
        "id": 383,
        "labels": [
            {
                "label": "Acer pseudoplatanus 'Leopoldii'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Gewone esdoorn cv. met bonte bladeren",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [24],
        "id": 384,
        "labels": [
            {
                "label": "Acer pseudoplatanus 'Prinz Handjery'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Gewone esdoorn met rood-geel gemarmerd blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [24],
        "id": 385,
        "labels": [
            {
                "label": "Acer pseudoplatanus 'Purpureum'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Gewone esdoorn met purperrode bladonderzijde",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 25,
        "labels": [
            {"label": "Acer rubrum", "language": "nl", "type": "prefLabel"},
            {"label": "rode esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [387],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [25],
        "id": 387,
        "labels": [
            {
                "label": "Acer rubrum 'October Glory'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 26,
        "labels": [
            {"label": "Acer rufinerve", "language": "nl", "type": "prefLabel"},
            {"label": "rossige slange-esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 27,
        "labels": [
            {"label": "Acer saccharinum", "language": "nl", "type": "prefLabel"},
            {"label": "zilveresdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [388],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [27],
        "id": 388,
        "labels": [
            {
                "label": "Acer saccharinum 'Laciniatum'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zilveresdoorn met ingesneden blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 28,
        "labels": [
            {"label": "Acer saccharum", "language": "nl", "type": "prefLabel"},
            {"label": "suikeresdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 29,
        "labels": [
            {"label": "Acer tataricum", "language": "nl", "type": "prefLabel"},
            {"label": "Tataarse esdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 30,
        "labels": [
            {"label": "Acer trautvetteri", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 31,
        "labels": [{"label": "Acer velutinum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1],
        "id": 32,
        "labels": [{"label": "Acer zoeschense", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2016,
        "labels": [
            {"label": "Actinidia", "language": "nl", "type": "prefLabel"},
            {"label": "straalstempel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [389, 390],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2016],
        "id": 389,
        "labels": [
            {"label": "Actinidia chinensis", "language": "nl", "type": "prefLabel"},
            {"label": "kiwi", "language": "nl", "type": "altLabel"},
            {"label": "Chinese kruisbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2016],
        "id": 390,
        "labels": [
            {"label": "Actinidia kolomikta", "language": "nl", "type": "prefLabel"},
            {"label": "bonte straalstempel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 33,
        "labels": [
            {"label": "Aesculus", "language": "la", "type": "prefLabel"},
            {"label": "paardenkastanje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [34, 35, 36, 37, 39, 40, 41, 42],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 34,
        "labels": [
            {"label": "Aesculus carnea (x)", "language": "nl", "type": "prefLabel"},
            {
                "label": "rode bastaardpaardenkastanje",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 35,
        "labels": [
            {"label": "Aesculus flava", "language": "nl", "type": "prefLabel"},
            {"label": "gele paardenkastanje", "language": "nl", "type": "altLabel"},
            {"label": "gele pavia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 36,
        "labels": [{"label": "Aesculus glabra", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 37,
        "labels": [
            {"label": "Aesculus hippocastanum", "language": "nl", "type": "prefLabel"},
            {"label": "witte paardenkastanje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [38, 391],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [37],
        "id": 38,
        "labels": [
            {
                "label": "Aesculus hippocastanum 'Memmingeri'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Witte paardenkastanje met wit-geel bestoven blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [37],
        "id": 391,
        "labels": [
            {
                "label": "Aesculus hippocastanum 'Wisselinck'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Witte paardenkastanje met geel gespikkeld blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 39,
        "labels": [{"label": "Aesculus indica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 40,
        "labels": [
            {"label": "Aesculus mutabilis (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 41,
        "labels": [
            {"label": "Aesculus parviflora", "language": "nl", "type": "prefLabel"},
            {"label": "herfstpaardenkastanje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [33],
        "id": 42,
        "labels": [{"label": "Aesculus pavia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2020,
        "labels": [{"label": "Ailanthus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [43],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2020],
        "id": 43,
        "labels": [
            {"label": "Ailanthus altissima", "language": "nl", "type": "prefLabel"},
            {"label": "hemelboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 44,
        "labels": [
            {"label": "Alnus", "language": "la", "type": "prefLabel"},
            {"label": "els", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [45, 46, 47, 48, 49, 50, 51, 52, 53],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 45,
        "labels": [
            {"label": "Alnus cordata", "language": "nl", "type": "prefLabel"},
            {"label": "hartbladige els", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 46,
        "labels": [{"label": "Alnus elliptica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 47,
        "labels": [
            {"label": "Alnus glutinosa", "language": "nl", "type": "prefLabel"},
            {"label": "zwarte els", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [368, 392],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [47],
        "id": 368,
        "labels": [
            {
                "label": "Alnus glutinosa 'Imperialis'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zwarte els met ingesneden blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [47],
        "id": 392,
        "labels": [
            {"label": "Alnus glutinosa 'Incisa'", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zwarte els met klein, diep ingesneden blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 48,
        "labels": [
            {"label": "Alnus incana", "language": "nl", "type": "prefLabel"},
            {"label": "witte els", "language": "nl", "type": "altLabel"},
            {"label": "grauwe els", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 49,
        "labels": [{"label": "Alnus japonica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 50,
        "labels": [
            {"label": "Alnus rubra", "language": "nl", "type": "prefLabel"},
            {"label": "rode els", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 51,
        "labels": [{"label": "Alnus rugosa", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 52,
        "labels": [
            {"label": "Alnus subcordata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [44],
        "id": 53,
        "labels": [
            {"label": "Alnus viridis", "language": "nl", "type": "prefLabel"},
            {"label": "alpenels", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2022,
        "labels": [{"label": "Aralia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [54],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2022],
        "id": 54,
        "labels": [
            {"label": "Aralia elata", "language": "nl", "type": "prefLabel"},
            {"label": "duivelswandelstok", "language": "nl", "type": "altLabel"},
            {"label": "engelenboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2023,
        "labels": [{"label": "Araucaria", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [513],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2023],
        "id": 513,
        "labels": [
            {"label": "Araucaria araucana", "language": "nl", "type": "prefLabel"},
            {"label": "apenboom", "language": "nl", "type": "altLabel"},
            {"label": "slangenden", "language": "nl", "type": "altLabel"},
            {"label": "apenverdriet", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 55,
        "labels": [
            {"label": "Betula", "language": "la", "type": "prefLabel"},
            {"label": "berk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            56,
            57,
            59,
            60,
            61,
            62,
            63,
            64,
            65,
            66,
            67,
            68,
            69,
            70,
            71,
            396,
            2031,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 396,
        "labels": [
            {"label": "Betula alleghaniensis", "language": "nl", "type": "prefLabel"},
            {"label": "gele berk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 56,
        "labels": [{"label": "Betula costata", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 57,
        "labels": [{"label": "Betula ermanii", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 59,
        "labels": [
            {"label": "Betula lenta", "language": "nl", "type": "prefLabel"},
            {"label": "suikerberk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 60,
        "labels": [
            {"label": "Betula maximowicziana", "language": "nl", "type": "prefLabel"},
            {"label": "grootbladige berk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 61,
        "labels": [
            {"label": "Betula medwediewii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 62,
        "labels": [
            {"label": "Betula middendorffii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 63,
        "labels": [
            {"label": "Betula nana", "language": "nl", "type": "prefLabel"},
            {"label": "dwergberk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 64,
        "labels": [
            {"label": "Betula nigra", "language": "nl", "type": "prefLabel"},
            {"label": "zwarte berk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 65,
        "labels": [
            {"label": "Betula papyrifera", "language": "nl", "type": "prefLabel"},
            {"label": "papierberk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 66,
        "labels": [
            {"label": "Betula pendula", "language": "nl", "type": "prefLabel"},
            {"label": "ruwe berk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [393, 394, 395, 673, 2029],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [66],
        "id": 393,
        "labels": [
            {
                "label": "Betula pendula 'Fastigiata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {"language": "nl", "note": "Zuilvormige ruwe berk", "type": "definition"}
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [66],
        "id": 394,
        "labels": [
            {
                "label": "Betula pendula 'Laciniata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Ruwe berk met ingesneden bladeren",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [66],
        "id": 395,
        "labels": [
            {
                "label": "Betula pendula 'Purpurea'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Ruwe berk met bruinrode bladeren",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [66],
        "id": 2029,
        "labels": [
            {
                "label": "Betula pendula 'Tristis'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "treurberk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [66],
        "id": 673,
        "labels": [
            {
                "label": "Betula pendula 'Youngii'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "prieelberk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 67,
        "labels": [
            {"label": "Betula platyphylla", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 68,
        "labels": [
            {"label": "Betula populifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 69,
        "labels": [
            {"label": "Betula potaninii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 70,
        "labels": [
            {"label": "Betula pubescens", "language": "nl", "type": "prefLabel"},
            {"label": "zachte berk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 71,
        "labels": [{"label": "Betula pumila", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [55],
        "id": 2031,
        "labels": [{"label": "Betula utilis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [58],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2031],
        "id": 58,
        "labels": [
            {
                "label": "Betula utilis 'jacquemontii'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 72,
        "labels": [
            {"label": "Buxus", "language": "la", "type": "prefLabel"},
            {"label": "palmboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [73],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [72],
        "id": 73,
        "labels": [
            {"label": "Buxus sempervirens", "language": "nl", "type": "prefLabel"},
            {"label": "gewone buxus", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [74, 628, 629, 75],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [73],
        "id": 628,
        "labels": [
            {
                "label": "Buxus sempervirens 'Argenteovariegata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [73],
        "id": 629,
        "labels": [
            {
                "label": "Buxus sempervirens 'Rotundifolia'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [73],
        "id": 74,
        "labels": [
            {
                "label": "Buxus sempervirens 'Sempervirens'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [73],
        "id": 75,
        "labels": [
            {
                "label": "Buxus sempervirens 'Suffruticosa'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "randpalm", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2032,
        "labels": [{"label": "Calocedrus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [397],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2032],
        "id": 397,
        "labels": [
            {"label": "Calocedrus decurrens", "language": "nl", "type": "prefLabel"},
            {"label": "Libocedrus decurrens", "language": "nl", "type": "altLabel"},
            {"label": "wierookcipres", "language": "nl", "type": "altLabel"},
            {"label": "wierookceder", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 398,
        "labels": [
            {"label": "Carpinus", "language": "la", "type": "prefLabel"},
            {"label": "haagbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [76, 77, 78, 79],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [398],
        "id": 76,
        "labels": [
            {"label": "Carpinus betulus", "language": "nl", "type": "prefLabel"},
            {"label": "gewone haagbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [399, 638],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [76],
        "id": 399,
        "labels": [
            {
                "label": "Carpinus betulus 'Fastigiata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zuilvormige cultuurvari\xebteit van gewone haagbeuk",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [76],
        "id": 638,
        "labels": [
            {
                "label": "Carpinus betulus 'Quercifolia'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [398],
        "id": 77,
        "labels": [
            {"label": "Carpinus caroliniana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [398],
        "id": 78,
        "labels": [
            {"label": "Carpinus cordata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [398],
        "id": 79,
        "labels": [
            {"label": "Carpinus orientalis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 80,
        "labels": [
            {"label": "Carya", "language": "la", "type": "prefLabel"},
            {"label": "hickorynoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [81, 82, 83, 400, 84],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 81,
        "labels": [
            {"label": "Carya cordiformis", "language": "nl", "type": "prefLabel"},
            {"label": "bitternoothickory", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 82,
        "labels": [
            {"label": "Carya glabra", "language": "nl", "type": "prefLabel"},
            {"label": "kale hickory", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 400,
        "labels": [
            {"label": "Carya laciniosa", "language": "nl", "type": "prefLabel"},
            {"label": "grootbladige hickory", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 83,
        "labels": [
            {"label": "Carya ovata", "language": "nl", "type": "prefLabel"},
            {"label": "ruigschorshickory", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [80],
        "id": 84,
        "labels": [
            {"label": "Carya tomentosa", "language": "nl", "type": "prefLabel"},
            {"label": "viltige hickory", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 85,
        "labels": [
            {"label": "Castanea", "language": "la", "type": "prefLabel"},
            {"label": "kastanje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [86, 87, 88],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [85],
        "id": 86,
        "labels": [
            {"label": "Castanea dentata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [85],
        "id": 87,
        "labels": [{"label": "Castanea pumila", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [85],
        "id": 88,
        "labels": [
            {"label": "Castanea sativa", "language": "nl", "type": "prefLabel"},
            {"label": "tamme kastanje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 89,
        "labels": [
            {"label": "Catalpa", "language": "la", "type": "prefLabel"},
            {"label": "trompetboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [90, 91, 92, 93, 94],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [89],
        "id": 90,
        "labels": [
            {"label": "Catalpa bignonioides", "language": "nl", "type": "prefLabel"},
            {"label": "gewone trompetboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [401],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [90],
        "id": 401,
        "labels": [
            {
                "label": "Catalpa bignonioides 'Aurea'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Trompetboom, cultuurvari\xebteit met geel blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [89],
        "id": 91,
        "labels": [{"label": "Catalpa bungei", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [89],
        "id": 92,
        "labels": [
            {"label": "Catalpa erubescens", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [89],
        "id": 93,
        "labels": [
            {"label": "Catalpa ovata", "language": "nl", "type": "prefLabel"},
            {"label": "gele trompetboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [89],
        "id": 94,
        "labels": [
            {"label": "Catalpa speciosa", "language": "nl", "type": "prefLabel"},
            {"label": "grote trompetboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2033,
        "labels": [{"label": "Cedrus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [514, 516, 517],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2033],
        "id": 514,
        "labels": [
            {"label": "Cedrus atlantica", "language": "nl", "type": "prefLabel"},
            {"label": "atlasceder", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [515],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [514],
        "id": 515,
        "labels": [
            {
                "label": "Cedrus atlantica 'Glauca'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "blauwe atlasceder", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2033],
        "id": 516,
        "labels": [
            {"label": "Cedrus deodara", "language": "nl", "type": "prefLabel"},
            {"label": "Himalayaceder", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [402],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [516],
        "id": 402,
        "labels": [
            {
                "label": "Cedrus deodara 'Albospica'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Himalayaceder met witachtige twijgen",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2033],
        "id": 517,
        "labels": [
            {"label": "Cedrus libanii", "language": "nl", "type": "prefLabel"},
            {"label": "Libanonceder", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2034,
        "labels": [{"label": "Celtis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [96, 97, 98],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2034],
        "id": 96,
        "labels": [
            {"label": "Celtis australis", "language": "nl", "type": "prefLabel"},
            {"label": "Europese netelboom", "language": "nl", "type": "altLabel"},
            {"label": "Oosterse netelboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2034],
        "id": 97,
        "labels": [
            {"label": "Celtis koraiensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2034],
        "id": 98,
        "labels": [
            {"label": "Celtis occidentalis", "language": "nl", "type": "prefLabel"},
            {"label": "zwepenboom", "language": "nl", "type": "altLabel"},
            {"label": "Amerikaanse netelboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2038,
        "labels": [{"label": "Cephalotaxus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [518],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2038],
        "id": 518,
        "labels": [
            {
                "label": "Cephalotaxus harringtonia",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2039,
        "labels": [
            {"label": "Cercidiphyllum", "language": "nl", "type": "prefLabel"},
            {"label": "katsoeraboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [99],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2039],
        "id": 99,
        "labels": [
            {"label": "Cercidiphyllum japonicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 100,
        "labels": [
            {"label": "Cercis", "language": "la", "type": "prefLabel"},
            {"label": "Judasboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [101, 102],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [100],
        "id": 101,
        "labels": [
            {"label": "Cercis canadensis", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse judasboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [403],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [101],
        "id": 403,
        "labels": [
            {
                "label": "Cercis canadensis 'Forest Pansy'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Amerikaanse judasboom met donkerrood blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [100],
        "id": 102,
        "labels": [
            {"label": "Cercis siliquastrum", "language": "nl", "type": "prefLabel"},
            {"label": "Europese judasboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 519,
        "labels": [
            {"label": "Chamaecyparis", "language": "la", "type": "prefLabel"},
            {"label": "dwergcypres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [520, 522, 523, 524],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [519],
        "id": 520,
        "labels": [
            {
                "label": "Chamaecyparis lawsoniana",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "Californische schijncipres",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [519],
        "id": 522,
        "labels": [
            {"label": "Chamaecyparis obtusa", "language": "nl", "type": "prefLabel"},
            {"label": "Hinokischijncipres", "language": "nl", "type": "altLabel"},
            {"label": "Hinokicipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [519],
        "id": 523,
        "labels": [
            {"label": "Chamaecyparis pisifera", "language": "nl", "type": "prefLabel"},
            {"label": "Sawaraschijncipres", "language": "nl", "type": "altLabel"},
            {"label": "Japanse cipres", "language": "nl", "type": "altLabel"},
            {"label": "Sawaracipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [519],
        "id": 524,
        "labels": [
            {"label": "Chamaecyparis thyoides", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2044,
        "labels": [
            {"label": "Cladrastis", "language": "nl", "type": "prefLabel"},
            {"label": "geelhout", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [103],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2044],
        "id": 103,
        "labels": [
            {"label": "Cladrastis kentukea", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaans geelhout", "language": "nl", "type": "altLabel"},
            {"label": "Cladrastis lutea", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2047,
        "labels": [
            {"label": "Clematis", "language": "nl", "type": "prefLabel"},
            {"label": "bosdruif", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [664],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2047],
        "id": 664,
        "labels": [
            {"label": "Clematis vitalba", "language": "nl", "type": "prefLabel"},
            {"label": "bosrank", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2049,
        "labels": [{"label": "Clerodendrum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [104],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2049],
        "id": 104,
        "labels": [
            {"label": "Clerodendrum trichotomum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 105,
        "labels": [
            {"label": "Clethra", "language": "la", "type": "prefLabel"},
            {"label": "schijnels", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [106, 107, 108, 109],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [105],
        "id": 106,
        "labels": [
            {"label": "Clethra acuminata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [105],
        "id": 107,
        "labels": [
            {"label": "Clethra alnifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [105],
        "id": 108,
        "labels": [
            {"label": "Clethra barbinervis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [105],
        "id": 109,
        "labels": [
            {"label": "Clethra tomentosa", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 110,
        "labels": [
            {"label": "Cornus", "language": "la", "type": "prefLabel"},
            {"label": "kornoelje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [111, 112, 113, 114, 404, 405, 115],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [110],
        "id": 404,
        "labels": [
            {"label": "Cornus alba", "language": "nl", "type": "prefLabel"},
            {"label": "witte kornoelje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [110],
        "id": 111,
        "labels": [
            {"label": "Cornus alternifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [110],
        "id": 112,
        "labels": [
            {"label": "Cornus controversa", "language": "nl", "type": "prefLabel"},
            {"label": "grote pagodekornoelje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [110],
        "id": 405,
        "labels": [
            {"label": "Cornus florida", "language": "nl", "type": "prefLabel"},
            {
                "label": "Oost-Aziatische kopkornoelje",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [110],
        "id": 113,
        "labels": [
            {"label": "Cornus kousa", "language": "nl", "type": "prefLabel"},
            {
                "label": "Oost-Amerikaanse kopkornoelje",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [110],
        "id": 114,
        "labels": [
            {"label": "Cornus mas", "language": "nl", "type": "prefLabel"},
            {"label": "gele kornoelje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2253],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [114],
        "id": 2253,
        "labels": [
            {"label": "Cornus mas 'Variegata'", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Cornus mas 'Variegata' is gele kornoelje met witgerand blad.",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [110],
        "id": 115,
        "labels": [
            {"label": "Cornus sanguinea", "language": "nl", "type": "prefLabel"},
            {"label": "rode kornoelje", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 116,
        "labels": [
            {"label": "Corylus", "language": "la", "type": "prefLabel"},
            {"label": "hazelaar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [117, 118, 119, 120, 122],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [116],
        "id": 117,
        "labels": [
            {"label": "Corylus americana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [116],
        "id": 118,
        "labels": [
            {"label": "Corylus avellana", "language": "nl", "type": "prefLabel"},
            {"label": "gewone hazelaar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [406, 407],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [118],
        "id": 406,
        "labels": [
            {
                "label": "Corylus avellana 'Heterophylla'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Hazelaar met veerspletige bladeren",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [118],
        "id": 407,
        "labels": [
            {
                "label": "Corylus avellana 'Pendula'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Treurvorm van gewone hazelaar",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [116],
        "id": 119,
        "labels": [
            {"label": "Corylus colurna", "language": "nl", "type": "prefLabel"},
            {"label": "Turkse boomhazelaar", "language": "nl", "type": "altLabel"},
            {"label": "boomhazelaar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [116],
        "id": 120,
        "labels": [
            {"label": "Corylus maxima", "language": "nl", "type": "prefLabel"},
            {"label": "Lambertsnoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [121],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [120],
        "id": 121,
        "labels": [
            {
                "label": "Corylus maxima 'Purpurea'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "bruine hazelaar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [116],
        "id": 122,
        "labels": [
            {"label": "Corylus sieboldiana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 625,
        "labels": [
            {"label": "Crataegus", "language": "la", "type": "prefLabel"},
            {"label": "meidoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            123,
            124,
            125,
            126,
            127,
            128,
            129,
            130,
            131,
            132,
            133,
            134,
            135,
            136,
            137,
            138,
            139,
            140,
            142,
            143,
            2054,
            144,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 123,
        "labels": [
            {"label": "Crataegus altaica", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 124,
        "labels": [
            {"label": "Crataegus azarolus", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 125,
        "labels": [
            {"label": "Crataegus chlorosarca", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 126,
        "labels": [
            {"label": "Crataegus chrysocarpa", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 127,
        "labels": [
            {"label": "Crataegus coccinioides", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 128,
        "labels": [
            {"label": "Crataegus crus-galli", "language": "nl", "type": "prefLabel"},
            {"label": "hanedoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 129,
        "labels": [
            {"label": "Crataegus durobrivensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 130,
        "labels": [
            {"label": "Crataegus grignonensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 131,
        "labels": [
            {"label": "Crataegus laciniata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 132,
        "labels": [
            {"label": "Crataegus laevigata", "language": "nl", "type": "prefLabel"},
            {"label": "tweestijlige meidoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [408, 409],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [132],
        "id": 408,
        "labels": [
            {
                "label": "Crataegus laevigata 'Mutabilis'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Tweestijlige meidoorn met gevulde bleekroze bloem",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [132],
        "id": 409,
        "labels": [
            {
                "label": "Crataegus laevigata 'Paul's scarlet'",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "rode tweestijlige meidoorn",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 133,
        "labels": [
            {"label": "Crataegus lavallei (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 134,
        "labels": [
            {"label": "Crataegus monogyna", "language": "nl", "type": "prefLabel"},
            {"label": "eenstijlige meidoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 135,
        "labels": [
            {"label": "Crataegus nigra", "language": "nl", "type": "prefLabel"},
            {"label": "Hongaarse meidoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 136,
        "labels": [
            {"label": "Crataegus pedicellata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 137,
        "labels": [
            {"label": "Crataegus pentagyna", "language": "nl", "type": "prefLabel"},
            {"label": "vijfstijlige meidoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 138,
        "labels": [
            {"label": "Crataegus phaenopyrum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 139,
        "labels": [
            {"label": "Crataegus pinnatifida", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 140,
        "labels": [
            {"label": "Crataegus prunifolia (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 2054,
        "labels": [
            {"label": "Crataegus pubescens", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [141],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2054],
        "id": 141,
        "labels": [
            {
                "label": "Crataegus pubescens f. stipulacea",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 142,
        "labels": [
            {"label": "Crataegus punctata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 143,
        "labels": [
            {"label": "Crataegus submollis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [625],
        "id": 144,
        "labels": [
            {"label": "Crataegus viridis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2055,
        "labels": [{"label": "Cryptomeria", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [525],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2055],
        "id": 525,
        "labels": [
            {"label": "Cryptomeria japonica", "language": "nl", "type": "prefLabel"},
            {"label": "sikkelcipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2056,
        "labels": [{"label": "Cunninghamia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [526],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2056],
        "id": 526,
        "labels": [
            {"label": "Cunninghamia lanceolata", "language": "nl", "type": "prefLabel"},
            {"label": "spiesden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2064,
        "labels": [{"label": "Cupressocyparis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [527],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2064],
        "id": 527,
        "labels": [
            {
                "label": "Cupressocyparis leylandii",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2059,
        "labels": [
            {"label": "Cupressus", "language": "nl", "type": "prefLabel"},
            {"label": "cipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [528, 529],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2059],
        "id": 528,
        "labels": [
            {"label": "Cupressus arizonica", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse cipres", "language": "nl", "type": "altLabel"},
            {"label": "Arizona cipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2059],
        "id": 529,
        "labels": [
            {"label": "Cupressus sempervirens", "language": "nl", "type": "prefLabel"},
            {"label": "Italiaanse cipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2065,
        "labels": [{"label": "Cydonia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [145],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2065],
        "id": 145,
        "labels": [
            {"label": "Cydonia oblonga", "language": "nl", "type": "prefLabel"},
            {"label": "kweepeer", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2066,
        "labels": [
            {"label": "Cytisus", "language": "nl", "type": "prefLabel"},
            {"label": "brem", "language": "nl", "type": "altLabel"},
            {"label": "geiteklaver", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [624],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2066],
        "id": 624,
        "labels": [
            {"label": "Cytisus scoparius", "language": "nl", "type": "prefLabel"},
            {"label": "bezembrem", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2069,
        "labels": [
            {"label": "Davidia", "language": "nl", "type": "prefLabel"},
            {"label": "zakdoekboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [146],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2069],
        "id": 146,
        "labels": [
            {"label": "Davidia involucrata", "language": "nl", "type": "prefLabel"},
            {"label": "vaantjesboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2071,
        "labels": [
            {"label": "Diospyros", "language": "nl", "type": "prefLabel"},
            {"label": "godenpeer", "language": "nl", "type": "altLabel"},
            {"label": "dadelpruim", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [147],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2071],
        "id": 147,
        "labels": [{"label": "Diospyros lotus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2073,
        "labels": [
            {"label": "Eleagnus", "language": "nl", "type": "prefLabel"},
            {"label": "olijfwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [148],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2073],
        "id": 148,
        "labels": [
            {"label": "Eleagnus angustifolia", "language": "nl", "type": "prefLabel"},
            {"label": "smalbladige olijfwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2076,
        "labels": [
            {"label": "Eucommia", "language": "nl", "type": "prefLabel"},
            {"label": "iepbladige gummiboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [149],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2076],
        "id": 149,
        "labels": [
            {"label": "Eucommia ulmoides", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2078,
        "labels": [
            {"label": "Euonymus", "language": "nl", "type": "prefLabel"},
            {"label": "gewone kardinaalsmuts", "language": "nl", "type": "altLabel"},
            {"label": "gewone kardinaalshoed", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [619],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2078],
        "id": 619,
        "labels": [
            {"label": "Euonymus europaeus", "language": "nl", "type": "prefLabel"},
            {"label": "Kardinaalsmuts", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 151,
        "labels": [
            {"label": "Fagus", "language": "la", "type": "prefLabel"},
            {"label": "beuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [152, 153, 154],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [151],
        "id": 152,
        "labels": [{"label": "Fagus englerana", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [151],
        "id": 153,
        "labels": [
            {"label": "Fagus grandifolia", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse beuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [151],
        "id": 154,
        "labels": [
            {"label": "Fagus sylvatica", "language": "nl", "type": "prefLabel"},
            {"label": "gewone beuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [155, 410, 411, 412, 413, 414, 415, 416, 417, 2331],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 410,
        "labels": [
            {
                "label": "Fagus sylvatica 'Albovariegata'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "witbonte beuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 411,
        "labels": [
            {
                "label": "Fagus sylvatica 'Asplenifolia'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "varenbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 155,
        "labels": [
            {
                "label": "Fagus sylvatica 'Atropunicea'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "bruine beuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 412,
        "labels": [
            {
                "label": "Fagus sylvatica 'Borneyensis'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 415,
        "labels": [
            {
                "label": "Fagus sylvatica 'Pendula'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "treurbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 416,
        "labels": [
            {
                "label": "Fagus sylvatica 'Purpureopendula'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "bruine treurbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 413,
        "labels": [
            {
                "label": "Fagus sylvatica 'Quercifolia'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "eikbladige beuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 414,
        "labels": [
            {
                "label": "Fagus sylvatica 'Quercoides'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Beuk met sterk gegroefde schors",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 417,
        "labels": [
            {
                "label": "Fagus sylvatica 'Tortuosa'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Beuk met gedraaide takken",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [154],
        "id": 2331,
        "labels": [
            {"label": "Fagus sylvatica 'Zlatia'", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 156,
        "labels": [
            {"label": "Fraxinus", "language": "la", "type": "prefLabel"},
            {"label": "es", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            157,
            158,
            160,
            161,
            163,
            167,
            168,
            169,
            171,
            172,
            173,
            174,
            2082,
            175,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 157,
        "labels": [
            {"label": "Fraxinus americana", "language": "nl", "type": "prefLabel"},
            {"label": "witte es", "language": "nl", "type": "altLabel"},
            {"label": "Amerikaanse es", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 158,
        "labels": [
            {"label": "Fraxinus angustifolia", "language": "nl", "type": "prefLabel"},
            {"label": "Fraxinus oxycarpa", "language": "nl", "type": "altLabel"},
            {"label": "smalbladige es", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [159],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [158],
        "id": 159,
        "labels": [
            {
                "label": "Fraxinus angustifolia 'Monophylla'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 160,
        "labels": [
            {"label": "Fraxinus biltmoreana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 161,
        "labels": [
            {"label": "Fraxinus bungeana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 2082,
        "labels": [
            {"label": "Fraxinus chinensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [162],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2082],
        "id": 162,
        "labels": [
            {
                "label": "Fraxinus chinensis var. rhynchophylla",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 163,
        "labels": [
            {"label": "Fraxinus exelsior", "language": "nl", "type": "prefLabel"},
            {"label": "gewone es", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [164, 165, 166, 418],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [163],
        "id": 164,
        "labels": [
            {
                "label": "Fraxinus exelsior 'Diversifolia'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "eenbladige es", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [163],
        "id": 418,
        "labels": [
            {
                "label": "Fraxinus exelsior 'Elegantissima'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Gewone es, cultuurvari\xebteit met onregelmatige kleine blaadjes"
                ),
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [163],
        "id": 165,
        "labels": [
            {
                "label": "Fraxinus exelsior 'Jaspidea'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [163],
        "id": 166,
        "labels": [
            {
                "label": "Fraxinus exelsior 'Pendula'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "treures", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 167,
        "labels": [
            {"label": "Fraxinus latifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 168,
        "labels": [
            {"label": "Fraxinus longicuspis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 169,
        "labels": [
            {"label": "Fraxinus ornus", "language": "nl", "type": "prefLabel"},
            {"label": "gewone pluimes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 171,
        "labels": [
            {"label": "Fraxinus paxiana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 172,
        "labels": [
            {"label": "Fraxinus pennsylvanica", "language": "nl", "type": "prefLabel"},
            {"label": "groene es", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [419],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [172],
        "id": 419,
        "labels": [
            {
                "label": "Fraxinus pennsylvanica 'Aucubifolia'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Groene es met geelgevlekte bladeren",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 173,
        "labels": [
            {"label": "Fraxinus spaethiana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 174,
        "labels": [
            {"label": "Fraxinus syriaca", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [156],
        "id": 175,
        "labels": [
            {"label": "Fraxinus xanthoxyloides", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1530,
        "labels": [{"label": "Ginkgo", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [530],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1530],
        "id": 530,
        "labels": [
            {"label": "Ginkgo biloba", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse notenboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2084,
        "labels": [
            {"label": "Gleditsia", "language": "nl", "type": "prefLabel"},
            {"label": "valse christusdoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [176],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2084],
        "id": 176,
        "labels": [
            {"label": "Gleditsia triacantos", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse gleditsia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [420],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [176],
        "id": 420,
        "labels": [
            {
                "label": "Gleditsia triacantos 'Inermis'",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "ongedoornde valse christusdoorn",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2086,
        "labels": [
            {"label": "Gymnocladus", "language": "nl", "type": "prefLabel"},
            {"label": "doodsbeenderenboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [177],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2086],
        "id": 177,
        "labels": [
            {"label": "Gymnocladus dioicus", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2087,
        "labels": [
            {"label": "Halesia", "language": "nl", "type": "prefLabel"},
            {"label": "sneeuwklokjesboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [178],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2087],
        "id": 178,
        "labels": [
            {"label": "Halesia carolina", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2088,
        "labels": [
            {"label": "Hedera", "language": "nl", "type": "prefLabel"},
            {"label": "klimop", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [663],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2088],
        "id": 663,
        "labels": [
            {"label": "Hedera helix", "language": "nl", "type": "prefLabel"},
            {"label": "gewone klimop", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2090,
        "labels": [
            {"label": "Ilex", "language": "nl", "type": "prefLabel"},
            {"label": "hulst", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [179, 2091],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2090],
        "id": 2091,
        "labels": [
            {"label": "Ilex altaclarensis (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [369],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2091],
        "id": 369,
        "labels": [
            {
                "label": "Ilex altaclarensis (x) 'Belgica'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "grootbladige hulst", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2090],
        "id": 179,
        "labels": [
            {"label": "Ilex aquifolium", "language": "nl", "type": "prefLabel"},
            {"label": "scherpe hulst", "language": "nl", "type": "altLabel"},
            {"label": "groene hulst", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [421],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [179],
        "id": 421,
        "labels": [
            {
                "label": "Ilex aquifolium 'Argenteomarginata'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "bonte beshulst", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 180,
        "labels": [
            {"label": "Juglans", "language": "la", "type": "prefLabel"},
            {"label": "walnoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [181, 182, 183, 184],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [180],
        "id": 181,
        "labels": [
            {"label": "Juglans ailantifolia", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse walnoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [180],
        "id": 182,
        "labels": [
            {"label": "Juglans cinerea", "language": "nl", "type": "prefLabel"},
            {"label": "grijze walnoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [180],
        "id": 183,
        "labels": [
            {"label": "Juglans nigra", "language": "nl", "type": "prefLabel"},
            {"label": "zwarte walnoot", "language": "nl", "type": "altLabel"},
            {"label": "bitternoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [180],
        "id": 184,
        "labels": [
            {"label": "Juglans regia", "language": "nl", "type": "prefLabel"},
            {"label": "okkernoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 531,
        "labels": [
            {"label": "Juniperus", "language": "la", "type": "prefLabel"},
            {"label": "jeneverbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 2262],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 534,
        "labels": [
            {"label": "Juniperus chinensis", "language": "nl", "type": "prefLabel"},
            {"label": "Chinese jeneverbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 535,
        "labels": [
            {"label": "Juniperus communis", "language": "nl", "type": "prefLabel"},
            {"label": "gewone jeneverbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 2262,
        "labels": [
            {"label": "Juniperus drupacea", "language": "nl", "type": "prefLabel"},
            {"label": "Syrische jeneverbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 536,
        "labels": [
            {"label": "Juniperus horizontalis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 537,
        "labels": [{"label": "Juniperus media", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 538,
        "labels": [
            {"label": "Juniperus procumbens", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 532,
        "labels": [
            {"label": "Juniperus recurva", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 539,
        "labels": [
            {"label": "Juniperus rigida", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 540,
        "labels": [
            {"label": "Juniperus sabina", "language": "nl", "type": "prefLabel"},
            {"label": "zevenboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 533,
        "labels": [
            {"label": "Juniperus scopulorum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 541,
        "labels": [
            {"label": "Juniperus squamata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [531],
        "id": 542,
        "labels": [
            {"label": "Juniperus virginia", "language": "nl", "type": "prefLabel"},
            {"label": "Virginische jeneverbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2096,
        "labels": [{"label": "Kalopanax", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [185],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2096],
        "id": 185,
        "labels": [
            {"label": "Kalopanax septemlobus", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2097,
        "labels": [{"label": "Koelreuteria", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [186],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2097],
        "id": 186,
        "labels": [
            {"label": "Koelreuteria paniculata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 187,
        "labels": [
            {"label": "Laburnum", "language": "la", "type": "prefLabel"},
            {"label": "goudenregen", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [188, 189],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [187],
        "id": 188,
        "labels": [
            {"label": "Laburnum alpinum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [187],
        "id": 189,
        "labels": [
            {"label": "Laburnum anagyroides", "language": "nl", "type": "prefLabel"},
            {"label": "gewone goudenregen", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 666,
        "labels": [
            {"label": "Larix", "language": "la", "type": "prefLabel"},
            {"label": "lariks", "language": "nl", "type": "altLabel"},
            {"label": "lork", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [543, 544, 545, 546, 547, 662],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [666],
        "id": 543,
        "labels": [
            {"label": "Larix decidua", "language": "nl", "type": "prefLabel"},
            {"label": "Europese lariks", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [666],
        "id": 544,
        "labels": [
            {"label": "Larix gmelinii", "language": "nl", "type": "prefLabel"},
            {"label": "Aziatische lariks", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [666],
        "id": 545,
        "labels": [
            {"label": "Larix kaempferi", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse lariks", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [666],
        "id": 546,
        "labels": [
            {"label": "Larix laricina", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse lariks", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [666],
        "id": 547,
        "labels": [
            {"label": "Larix sibirica", "language": "nl", "type": "prefLabel"},
            {"label": "Siberische lariks", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [666],
        "id": 662,
        "labels": [
            {"label": "Larix x pendula", "language": "nl", "type": "prefLabel"},
            {"label": "treurlariks", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2099,
        "labels": [
            {"label": "Ligustrum", "language": "nl", "type": "prefLabel"},
            {"label": "liguster", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [422, 620],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2099],
        "id": 422,
        "labels": [
            {"label": "Ligustrum ovalifolium", "language": "nl", "type": "prefLabel"},
            {"label": "haagliguster", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [423],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [422],
        "id": 423,
        "labels": [
            {
                "label": "Ligustrum ovalifolium 'Aureum'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Gele of geelgevlekte haagliguster",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2099],
        "id": 620,
        "labels": [
            {"label": "Ligustrum vulgare", "language": "nl", "type": "prefLabel"},
            {"label": "gewone liguster", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2101,
        "labels": [
            {"label": "Liquidambar", "language": "nl", "type": "prefLabel"},
            {"label": "amberboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [190],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2101],
        "id": 190,
        "labels": [
            {"label": "Liquidambar styraciflua", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse amberboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [424],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [190],
        "id": 424,
        "labels": [
            {
                "label": "Liquidambar styraciflua 'Aurora'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2103,
        "labels": [
            {"label": "Liriodendron", "language": "nl", "type": "prefLabel"},
            {"label": "tulpenboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [191],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2103],
        "id": 191,
        "labels": [
            {"label": "Liriodendron tulipifera", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse tulpenboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [425, 426, 2255],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [191],
        "id": 425,
        "labels": [
            {
                "label": "Liriodendron tulipifera 'Aureomarginata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Tulpenboom met groen-geelgerand en gevlekt blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [191],
        "id": 426,
        "labels": [
            {
                "label": "Liriodendron tulipifera 'Integrifolia'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Tulpenboom, cultuurvari\xebteit met weinig ingesneden blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [191],
        "id": 2255,
        "labels": [
            {
                "label": "Liriodendron tulipifera 'Mediopictum'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2105,
        "labels": [
            {"label": "Lonicera", "language": "nl", "type": "prefLabel"},
            {"label": "kamperfoelie", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [631],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2105],
        "id": 631,
        "labels": [
            {"label": "Lonicera periclymenum", "language": "nl", "type": "prefLabel"},
            {"label": "boskamperfoelie", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2108,
        "labels": [{"label": "Maackia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2109],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2108],
        "id": 2109,
        "labels": [
            {"label": "Maackia amurensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [192],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2109],
        "id": 192,
        "labels": [
            {
                "label": "Maackia amurensis var. buergeri",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2110,
        "labels": [
            {"label": "Magnolia", "language": "nl", "type": "prefLabel"},
            {"label": "beverboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 427],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 193,
        "labels": [
            {"label": "Magnolia acuminata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 194,
        "labels": [
            {"label": "Magnolia grandiflora", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 195,
        "labels": [
            {"label": "Magnolia hypoleuca", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse kransmagnolia", "language": "nl", "type": "altLabel"},
            {"label": "Magnolia obovata", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 196,
        "labels": [{"label": "Magnolia kobus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 197,
        "labels": [
            {"label": "Magnolia macrophylla", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 427,
        "labels": [
            {"label": "Magnolia stellata", "language": "nl", "type": "prefLabel"},
            {"label": "stermagnolia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 198,
        "labels": [
            {"label": "Magnolia tripetala", "language": "nl", "type": "prefLabel"},
            {
                "label": "Amerikaanse kransmagnolia",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 199,
        "labels": [
            {"label": "Magnolia virginiana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 200,
        "labels": [
            {"label": "Magnolia wiesneri (x)", "language": "nl", "type": "prefLabel"},
            {"label": "Magnolia watsonii", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 201,
        "labels": [
            {"label": "Magnolia wilsonii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2110],
        "id": 202,
        "labels": [
            {"label": "Magnolia x soulangeana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2114,
        "labels": [{"label": "Mahonia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [428],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2114],
        "id": 428,
        "labels": [
            {"label": "Mahonia aquifolium", "language": "nl", "type": "prefLabel"},
            {"label": "gewone mahonia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 203,
        "labels": [
            {"label": "Malus", "language": "la", "type": "prefLabel"},
            {"label": "appelboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            204,
            205,
            206,
            207,
            208,
            209,
            210,
            211,
            212,
            213,
            214,
            215,
            216,
            217,
            218,
            219,
            220,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 204,
        "labels": [
            {"label": "Malus atrosanguinea (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 205,
        "labels": [{"label": "Malus baccata", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 206,
        "labels": [{"label": "Malus coronaria", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 207,
        "labels": [{"label": "Malus domestica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 208,
        "labels": [
            {"label": "Malus floribunda", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 209,
        "labels": [{"label": "Malus halliana", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 210,
        "labels": [
            {"label": "Malus hupehensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 211,
        "labels": [{"label": "Malus ioensis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 212,
        "labels": [
            {"label": "Malus kansuensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 213,
        "labels": [
            {"label": "Malus micromalus (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 214,
        "labels": [{"label": "Malus pratii", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 215,
        "labels": [
            {"label": "Malus prunifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 216,
        "labels": [
            {"label": "Malus robusta (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 217,
        "labels": [
            {"label": "Malus scheideckeri (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 218,
        "labels": [
            {"label": "Malus sylvestris", "language": "nl", "type": "prefLabel"},
            {"label": "wilde appel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 219,
        "labels": [
            {"label": "Malus toringoides", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [203],
        "id": 220,
        "labels": [
            {"label": "Malus yunnanensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2115,
        "labels": [{"label": "Mespilus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [221],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2115],
        "id": 221,
        "labels": [
            {"label": "Mespilus germanica", "language": "nl", "type": "prefLabel"},
            {"label": "mispel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2116,
        "labels": [
            {"label": "Metasequoia", "language": "nl", "type": "prefLabel"},
            {"label": "Chinese moerascipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [549],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2116],
        "id": 549,
        "labels": [
            {
                "label": "Metasequoia glyptostoboides",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "watercipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 222,
        "labels": [
            {"label": "Morus", "language": "la", "type": "prefLabel"},
            {"label": "moerbei", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [223, 224],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [222],
        "id": 223,
        "labels": [
            {"label": "Morus alba", "language": "nl", "type": "prefLabel"},
            {"label": "witte moerbei", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [222],
        "id": 224,
        "labels": [
            {"label": "Morus nigra", "language": "nl", "type": "prefLabel"},
            {"label": "zwarte moerbei", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2118,
        "labels": [
            {"label": "Nothofagus", "language": "nl", "type": "prefLabel"},
            {"label": "schijnbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [225],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2118],
        "id": 225,
        "labels": [
            {"label": "Nothofagus antarctica", "language": "nl", "type": "prefLabel"},
            {"label": "kaneelschijnbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2120,
        "labels": [
            {"label": "Nyssa", "language": "nl", "type": "prefLabel"},
            {"label": "tupeloboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [226],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2120],
        "id": 226,
        "labels": [{"label": "Nyssa sylvatica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2121,
        "labels": [
            {"label": "Osmanthus", "language": "nl", "type": "prefLabel"},
            {"label": "schijnhulst", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [429],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2121],
        "id": 429,
        "labels": [
            {"label": "Osmanthus heterophyllus", "language": "nl", "type": "prefLabel"},
            {"label": "gewone schijnhulst", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 227,
        "labels": [
            {"label": "Ostrya", "language": "la", "type": "prefLabel"},
            {"label": "hopbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [228, 229, 430],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [227],
        "id": 228,
        "labels": [
            {"label": "Ostrya carpinifolia", "language": "nl", "type": "prefLabel"},
            {"label": "Europese hopbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [227],
        "id": 430,
        "labels": [
            {"label": "Ostrya japonica", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse hopbeuk", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [227],
        "id": 229,
        "labels": [
            {"label": "Ostrya virginiana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1230,
        "labels": [{"label": "Parrotia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [230],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1230],
        "id": 230,
        "labels": [
            {"label": "Parrotia persica", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2123,
        "labels": [{"label": "Parrotiopsis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [231],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2123],
        "id": 231,
        "labels": [
            {
                "label": "Parrotiopsis jacquemontiana",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2124,
        "labels": [
            {"label": "Parthenocissus", "language": "nl", "type": "prefLabel"},
            {"label": "wilde wingerd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [431],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2124],
        "id": 431,
        "labels": [
            {
                "label": "Parthenocissus tricuspidata",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "driebladige napjeswingerd",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2126,
        "labels": [{"label": "Paulownia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [232],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2126],
        "id": 232,
        "labels": [
            {"label": "Paulownia tomentosa", "language": "nl", "type": "prefLabel"},
            {"label": "Anna Paulownaboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 233,
        "labels": [
            {"label": "Phellodendron", "language": "la", "type": "prefLabel"},
            {"label": "kurkboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [234, 236],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [233],
        "id": 234,
        "labels": [
            {"label": "Phellodendron amurense", "language": "nl", "type": "prefLabel"},
            {"label": "amurkurkboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [233],
        "id": 236,
        "labels": [
            {"label": "Phellodendron japonicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2127,
        "labels": [{"label": "Philadelphus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [235],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2127],
        "id": 235,
        "labels": [
            {"label": "Philadelphus coronarius", "language": "nl", "type": "prefLabel"},
            {"label": "boerenjasmijn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 550,
        "labels": [
            {"label": "Picea", "language": "la", "type": "prefLabel"},
            {"label": "spar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            551,
            552,
            553,
            554,
            555,
            556,
            557,
            558,
            559,
            560,
            561,
            562,
            563,
            564,
            565,
            566,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 551,
        "labels": [
            {"label": "Picea abies", "language": "nl", "type": "prefLabel"},
            {"label": "fijnspar", "language": "nl", "type": "altLabel"},
            {"label": "kerstspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 552,
        "labels": [
            {"label": "Picea alcoquiana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 553,
        "labels": [{"label": "Picea asperata", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 554,
        "labels": [
            {"label": "Picea brachytyla", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 555,
        "labels": [{"label": "Picea brewerana", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 556,
        "labels": [
            {"label": "Picea engelmannii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 557,
        "labels": [
            {"label": "Picea glauca", "language": "nl", "type": "prefLabel"},
            {"label": "witte spar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 558,
        "labels": [
            {"label": "Picea jezoensis", "language": "nl", "type": "prefLabel"},
            {"label": "Oost-Aziatische spar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 559,
        "labels": [
            {"label": "Picea likiangensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 560,
        "labels": [
            {"label": "Picea mariana", "language": "nl", "type": "prefLabel"},
            {"label": "zwarte spar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 561,
        "labels": [
            {"label": "Picea omorika", "language": "nl", "type": "prefLabel"},
            {"label": "Servische spar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 562,
        "labels": [
            {"label": "Picea orientalis", "language": "nl", "type": "prefLabel"},
            {"label": "Kaukasische spar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 563,
        "labels": [
            {"label": "Picea pungens", "language": "nl", "type": "prefLabel"},
            {"label": "sierspar", "language": "nl", "type": "altLabel"},
            {"label": "blauwe spar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 564,
        "labels": [
            {"label": "Picea sitchensis", "language": "nl", "type": "prefLabel"},
            {"label": "Sitkaspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 565,
        "labels": [{"label": "Picea smithiana", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [550],
        "id": 566,
        "labels": [{"label": "Picea torano", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2130,
        "labels": [{"label": "Pieris", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [237, 238, 239],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2130],
        "id": 237,
        "labels": [
            {"label": "Pieris floribunda", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2130],
        "id": 238,
        "labels": [
            {"label": "Pieris forrestii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2130],
        "id": 239,
        "labels": [{"label": "Pieris japonica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 567,
        "labels": [
            {"label": "Pinus", "language": "la", "type": "prefLabel"},
            {"label": "den", "language": "nl", "type": "altLabel"},
            {"label": "pijn", "language": "nl", "type": "altLabel"},
            {"label": "pijnboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            568,
            569,
            570,
            571,
            572,
            573,
            574,
            575,
            576,
            577,
            581,
            582,
            583,
            584,
            585,
            586,
            587,
            589,
            590,
            591,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 568,
        "labels": [{"label": "Pinus aristata", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 569,
        "labels": [
            {"label": "Pinus banksiana", "language": "nl", "type": "prefLabel"},
            {"label": "struikden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 570,
        "labels": [
            {"label": "Pinus cembra", "language": "nl", "type": "prefLabel"},
            {"label": "alpenden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 571,
        "labels": [
            {"label": "Pinus contorta", "language": "nl", "type": "prefLabel"},
            {"label": "draaiden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 572,
        "labels": [
            {"label": "Pinus densiflora", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse rode den", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 573,
        "labels": [{"label": "Pinus flexilis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 574,
        "labels": [{"label": "Pinus jeffreyi", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 575,
        "labels": [
            {"label": "Pinus leucodermis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 576,
        "labels": [
            {"label": "Pinus mugo", "language": "nl", "type": "prefLabel"},
            {"label": "bergden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 577,
        "labels": [
            {"label": "Pinus nigra", "language": "nl", "type": "prefLabel"},
            {"label": "zwarte den", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [579, 580],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [577],
        "id": 579,
        "labels": [
            {
                "label": "Pinus nigra subsp. laricio",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "Corsicaanse den", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [577],
        "id": 580,
        "labels": [
            {
                "label": "Pinus nigra subsp. nigra",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "Oosterijkse den", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 581,
        "labels": [
            {"label": "Pinus parviflora", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse witte den", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 582,
        "labels": [
            {"label": "Pinus peuce", "language": "nl", "type": "prefLabel"},
            {"label": "Balkanden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 583,
        "labels": [
            {"label": "Pinus pinaster", "language": "nl", "type": "prefLabel"},
            {"label": "zeeden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 584,
        "labels": [
            {"label": "Pinus ponderosa", "language": "nl", "type": "prefLabel"},
            {"label": "gele den", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 585,
        "labels": [
            {"label": "Pinus pumila", "language": "nl", "type": "prefLabel"},
            {"label": "dwergden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 586,
        "labels": [
            {"label": "Pinus rigida", "language": "nl", "type": "prefLabel"},
            {"label": "pekden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 587,
        "labels": [
            {"label": "Pinus strobus", "language": "nl", "type": "prefLabel"},
            {"label": "Weymouthden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [588],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [587],
        "id": 588,
        "labels": [
            {"label": "Pinus strobus 'Radiata'", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 589,
        "labels": [
            {"label": "Pinus sylvestris", "language": "nl", "type": "prefLabel"},
            {"label": "grove den", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 590,
        "labels": [
            {"label": "Pinus thunbergiana", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse zwarte den", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [567],
        "id": 591,
        "labels": [
            {"label": "Pinus wallichiana", "language": "nl", "type": "prefLabel"},
            {"label": "tranenden", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 240,
        "labels": [
            {"label": "Platanus", "language": "la", "type": "prefLabel"},
            {"label": "plataan", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [241, 242, 243],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [240],
        "id": 241,
        "labels": [
            {"label": "Platanus hispanica (x)", "language": "nl", "type": "prefLabel"},
            {"label": "gewone plataan", "language": "nl", "type": "altLabel"},
            {"label": "Platanus acerifolia (x)", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [240],
        "id": 242,
        "labels": [
            {"label": "Platanus occidentalis", "language": "nl", "type": "prefLabel"},
            {"label": "westerse plataan", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [240],
        "id": 243,
        "labels": [
            {"label": "Platanus orientalis", "language": "nl", "type": "prefLabel"},
            {"label": "oosterse plataan", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2329,
        "labels": [{"label": "Pontcirus", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2330],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2329],
        "id": 2330,
        "labels": [
            {"label": "Pontcirus trifoliata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 244,
        "labels": [
            {"label": "Populus", "language": "la", "type": "prefLabel"},
            {"label": "populier", "language": "nl", "type": "altLabel"},
            {"label": "peppel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            245,
            246,
            247,
            248,
            249,
            250,
            252,
            253,
            254,
            255,
            256,
            257,
            259,
            260,
            261,
            262,
            263,
            251,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 245,
        "labels": [
            {"label": "Populus alba", "language": "nl", "type": "prefLabel"},
            {"label": "witte abeel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 246,
        "labels": [
            {"label": "Populus angustifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 247,
        "labels": [
            {"label": "Populus balsamifera", "language": "nl", "type": "prefLabel"},
            {"label": "balsempopulier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 248,
        "labels": [
            {"label": "Populus berolinensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 249,
        "labels": [
            {"label": "Populus canadensis (x)", "language": "nl", "type": "prefLabel"},
            {"label": "Canadapopulier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [432, 622, 672],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [249],
        "id": 622,
        "labels": [
            {
                "label": "Populus canadensis (x) 'Marilandica'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [249],
        "id": 672,
        "labels": [
            {
                "label": "Populus canadensis (x) 'Serotina'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [249],
        "id": 432,
        "labels": [
            {
                "label": "Populus canadensis (x) 'Serotina de Selys'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Canadapopulier, zuilvormige cultuurvari\xebteit",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 250,
        "labels": [
            {"label": "Populus candicans", "language": "nl", "type": "prefLabel"},
            {"label": "Ontariopopulier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 251,
        "labels": [
            {"label": "Populus canescens (x)", "language": "nl", "type": "prefLabel"},
            {"label": "grauwe abeel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 252,
        "labels": [
            {"label": "Populus deltoides", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse populier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 253,
        "labels": [{"label": "Populus koreana", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 254,
        "labels": [
            {"label": "Populus lasiocarpa", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 255,
        "labels": [
            {"label": "Populus laurifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 256,
        "labels": [
            {"label": "Populus maximowiczii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 257,
        "labels": [
            {"label": "Populus nigra", "language": "nl", "type": "prefLabel"},
            {"label": "zwarte populier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [258],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [257],
        "id": 258,
        "labels": [
            {"label": "Populus nigra 'Italica'", "language": "nl", "type": "prefLabel"},
            {"label": "Italiaanse populier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 259,
        "labels": [{"label": "Populus simonii", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 260,
        "labels": [
            {"label": "Populus tremula", "language": "nl", "type": "prefLabel"},
            {"label": "ratelpopulier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 261,
        "labels": [
            {"label": "Populus tremuloides", "language": "nl", "type": "prefLabel"},
            {
                "label": "Amerikaanse ratelpopulier",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 262,
        "labels": [
            {"label": "Populus trichocarpa", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [244],
        "id": 263,
        "labels": [
            {"label": "Populus wilsonii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 632,
        "labels": [{"label": "Prunus", "language": "la", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            264,
            265,
            266,
            267,
            269,
            270,
            271,
            272,
            273,
            274,
            275,
            276,
            277,
            278,
            279,
            280,
            281,
            282,
            283,
            284,
            285,
            617,
            653,
            655,
            2140,
            2142,
            2250,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 264,
        "labels": [
            {
                "label": "Prunus amygdalopersica (x)",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 265,
        "labels": [
            {"label": "Prunus armeniaca", "language": "nl", "type": "prefLabel"},
            {"label": "abrikoos", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 266,
        "labels": [
            {"label": "Prunus avium", "language": "nl", "type": "prefLabel"},
            {"label": "zoete kers", "language": "nl", "type": "altLabel"},
            {"label": "kriek", "language": "nl", "type": "altLabel"},
            {"label": "boskers", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 267,
        "labels": [
            {"label": "Prunus cerasifera", "language": "nl", "type": "prefLabel"},
            {"label": "kerspruim", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [268],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [267],
        "id": 268,
        "labels": [
            {
                "label": "Prunus cerasifera 'Nigra'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Kerspruim, cultuurvari\xebteit met donkerrood blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 269,
        "labels": [
            {"label": "Prunus cerasus", "language": "nl", "type": "prefLabel"},
            {"label": "zure kers", "language": "nl", "type": "altLabel"},
            {"label": "waal", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 270,
        "labels": [
            {"label": "Prunus conradinae", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 271,
        "labels": [
            {"label": "Prunus domestica", "language": "nl", "type": "prefLabel"},
            {"label": "pruim", "language": "nl", "type": "altLabel"},
            {"label": "kwets", "language": "nl", "type": "altLabel"},
            {"label": "brompton", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 272,
        "labels": [
            {"label": "Prunus dulcis", "language": "nl", "type": "prefLabel"},
            {"label": "amandel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 273,
        "labels": [
            {"label": "Prunus fruticosa", "language": "nl", "type": "prefLabel"},
            {"label": "dwergkers", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 274,
        "labels": [
            {"label": "Prunus insititia", "language": "nl", "type": "prefLabel"},
            {"label": "kroospruim", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 2140,
        "labels": [
            {"label": "Prunus laurocerasus", "language": "nl", "type": "prefLabel"},
            {"label": "gewone laurierkers", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 2142,
        "labels": [
            {"label": "Prunus lusitanica", "language": "nl", "type": "prefLabel"},
            {"label": "Portugese laurierkers", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 275,
        "labels": [
            {"label": "Prunus mahaleb", "language": "nl", "type": "prefLabel"},
            {"label": "Weichelboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 276,
        "labels": [
            {"label": "Prunus mume", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse abrikoos", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 2250,
        "labels": [
            {"label": "Prunus padus", "language": "nl", "type": "prefLabel"},
            {"label": "Europese vogelkers", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 277,
        "labels": [
            {"label": "Prunus persica", "language": "nl", "type": "prefLabel"},
            {"label": "perzik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 278,
        "labels": [
            {"label": "Prunus pilosiuscula", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 279,
        "labels": [
            {"label": "Prunus sargentii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 653,
        "labels": [
            {"label": "Prunus serotina", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse vogelkers", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 280,
        "labels": [
            {"label": "Prunus serrulata", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse sierkers", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 281,
        "labels": [{"label": "Prunus speciosa", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 617,
        "labels": [
            {"label": "Prunus spinosa", "language": "nl", "type": "prefLabel"},
            {"label": "sleedoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 282,
        "labels": [
            {"label": "Prunus subhirtella", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 283,
        "labels": [
            {"label": "Prunus tenella", "language": "nl", "type": "prefLabel"},
            {"label": "dwergamandel", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 284,
        "labels": [
            {"label": "Prunus virginiana", "language": "nl", "type": "prefLabel"},
            {"label": "Virginische vogelkers", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 655,
        "labels": [
            {"label": "Prunus x fruticans", "language": "nl", "type": "prefLabel"},
            {"label": "heesterpruim", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [632],
        "id": 285,
        "labels": [
            {"label": "Prunus yedoensis (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2144,
        "labels": [{"label": "Pseudolarix", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [592],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2144],
        "id": 592,
        "labels": [
            {"label": "Pseudolarix kaempferi", "language": "nl", "type": "prefLabel"},
            {"label": "goudlork", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2145,
        "labels": [{"label": "Pseudotsuga", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [593],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2145],
        "id": 593,
        "labels": [
            {"label": "Pseudotsuga menziesii", "language": "nl", "type": "prefLabel"},
            {"label": "Douglasspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2146,
        "labels": [{"label": "Ptelea", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [286],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2146],
        "id": 286,
        "labels": [
            {"label": "Ptelea trifoliata", "language": "nl", "type": "prefLabel"},
            {"label": "lederboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 287,
        "labels": [
            {"label": "Pterocarya", "language": "la", "type": "prefLabel"},
            {"label": "vleugelnoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [288, 289, 290],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [287],
        "id": 288,
        "labels": [
            {"label": "Pterocarya fraxinifolia", "language": "nl", "type": "prefLabel"},
            {"label": "Kaukasische vleugelnoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [287],
        "id": 289,
        "labels": [
            {"label": "Pterocarya rhoifolia", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse vleugelnoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [287],
        "id": 290,
        "labels": [
            {"label": "Pterocarya stenoptera", "language": "nl", "type": "prefLabel"},
            {"label": "Chinese vleugelnoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2147,
        "labels": [{"label": "Pterostyrax", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [291],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2147],
        "id": 291,
        "labels": [
            {"label": "Pterostyrax hispida", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 292,
        "labels": [
            {"label": "Pyrus", "language": "la", "type": "prefLabel"},
            {"label": "peerboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [293, 294, 295, 296, 2256, 2260],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [292],
        "id": 293,
        "labels": [
            {"label": "Pyrus amygdaliformis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [292],
        "id": 294,
        "labels": [
            {"label": "Pyrus communis", "language": "nl", "type": "prefLabel"},
            {"label": "gewone peerboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [292],
        "id": 2260,
        "labels": [
            {
                "label": "Pyrus communis subsp. Pyraster",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "wilde peer", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [292],
        "id": 2256,
        "labels": [
            {
                "label": "Pyrus communis var. sativa",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "Pyrus communis subsp. communis",
                "language": "nl",
                "type": "altLabel",
            },
            {"label": "cultuurpeer", "language": "nl", "type": "altLabel"},
            {"label": "gekweekte peer", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [292],
        "id": 295,
        "labels": [
            {"label": "Pyrus salicifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [292],
        "id": 296,
        "labels": [
            {"label": "Pyrus ussuriensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 297,
        "labels": [
            {"label": "Quercus", "language": "la", "type": "prefLabel"},
            {"label": "eik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            298,
            299,
            300,
            301,
            302,
            303,
            304,
            305,
            306,
            307,
            308,
            309,
            310,
            311,
            312,
            313,
            314,
            315,
            316,
            317,
            318,
            319,
            320,
            321,
            322,
            323,
            439,
            440,
            2150,
            325,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 298,
        "labels": [
            {"label": "Quercus acutissima", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 299,
        "labels": [{"label": "Quercus bicolor", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 300,
        "labels": [
            {"label": "Quercus canariensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 301,
        "labels": [
            {"label": "Quercus castaneifolia", "language": "nl", "type": "prefLabel"},
            {"label": "kastanjebladeik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 302,
        "labels": [
            {"label": "Quercus cerris", "language": "nl", "type": "prefLabel"},
            {"label": "moseik", "language": "nl", "type": "altLabel"},
            {"label": "Turkse eik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 303,
        "labels": [
            {"label": "Quercus coccinea", "language": "nl", "type": "prefLabel"},
            {"label": "scharlakeneik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 304,
        "labels": [
            {"label": "Quercus frainetto", "language": "nl", "type": "prefLabel"},
            {"label": "Hongaarse eik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 305,
        "labels": [
            {"label": "Quercus glandulifera", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 306,
        "labels": [
            {"label": "Quercus heterophylla (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 307,
        "labels": [
            {"label": "Quercus hispanica (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 308,
        "labels": [
            {"label": "Quercus ilex", "language": "nl", "type": "prefLabel"},
            {"label": "steeneik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 309,
        "labels": [
            {"label": "Quercus ilicifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 310,
        "labels": [
            {"label": "Quercus imbricaria", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 439,
        "labels": [
            {"label": "Quercus laurifolia", "language": "nl", "type": "prefLabel"},
            {"label": "zuidelijke lauriereik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 311,
        "labels": [{"label": "Quercus libani", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 312,
        "labels": [
            {"label": "Quercus macranthera", "language": "nl", "type": "prefLabel"},
            {"label": "Perzische eik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 440,
        "labels": [
            {"label": "Quercus marilandica", "language": "nl", "type": "prefLabel"},
            {"label": "Maryland eik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 313,
        "labels": [
            {"label": "Quercus palustris", "language": "nl", "type": "prefLabel"},
            {"label": "moeraseik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 314,
        "labels": [
            {"label": "Quercus petraea", "language": "nl", "type": "prefLabel"},
            {"label": "wintereik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [441],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [314],
        "id": 441,
        "labels": [
            {
                "label": "Quercus petraea 'Mespilifolia'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "mispelbladige wintereik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 315,
        "labels": [
            {"label": "Quercus phellos", "language": "nl", "type": "prefLabel"},
            {"label": "wilgenbladeik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 316,
        "labels": [{"label": "Quercus pontica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 317,
        "labels": [
            {"label": "Quercus prinoides", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 318,
        "labels": [
            {"label": "Quercus prinus", "language": "nl", "type": "prefLabel"},
            {"label": "kastanje-eik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 319,
        "labels": [
            {"label": "Quercus pubescens", "language": "nl", "type": "prefLabel"},
            {"label": "zachte eik", "language": "nl", "type": "altLabel"},
            {"label": "donzige eik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 320,
        "labels": [
            {"label": "Quercus pyrenaica", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 321,
        "labels": [
            {"label": "Quercus robur", "language": "nl", "type": "prefLabel"},
            {"label": "zomereik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [433, 434, 435, 436, 437, 639, 438],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [321],
        "id": 433,
        "labels": [
            {
                "label": "Quercus robur 'Albomarmorata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zomereik met witgemarmerd blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [321],
        "id": 434,
        "labels": [
            {
                "label": "Quercus robur 'Argentomarginata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zomereik met witgerand blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [321],
        "id": 435,
        "labels": [
            {
                "label": "Quercus robur 'Fastigiata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "Zuilvormige eik", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [321],
        "id": 436,
        "labels": [
            {
                "label": "Quercus robur 'Fastigiata Cucullata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zuilvormige zomereik en bolstaand blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [321],
        "id": 437,
        "labels": [
            {
                "label": "Quercus robur 'Filicifolia'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zomereik met lijnvormig ingesneden bladeren",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [321],
        "id": 639,
        "labels": [
            {"label": "Quercus robur 'Pendula'", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [321],
        "id": 438,
        "labels": [
            {
                "label": "Quercus robur 'Strypemonde'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zomereik met smalle, onregelmatig gevormde bladeren",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 322,
        "labels": [
            {"label": "Quercus rubra", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse eik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 323,
        "labels": [
            {"label": "Quercus schochiana (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2150],
        "id": 324,
        "labels": [
            {
                "label": "Quercus turneri 'Pseudoturneri' (x)",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 2150,
        "labels": [
            {"label": "Quercus turneri (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [324],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [297],
        "id": 325,
        "labels": [
            {"label": "Quercus velutina", "language": "nl", "type": "prefLabel"},
            {"label": "blikeik", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 326,
        "labels": [
            {"label": "Rhamnus", "language": "la", "type": "prefLabel"},
            {"label": "vuilboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [327, 328],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [326],
        "id": 327,
        "labels": [
            {"label": "Rhamnus catharticus", "language": "nl", "type": "prefLabel"},
            {"label": "wegedoorn", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [326],
        "id": 328,
        "labels": [
            {"label": "Rhamnus frangula", "language": "nl", "type": "prefLabel"},
            {"label": "gewone vuilboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2151,
        "labels": [{"label": "Rhododendron", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [329],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2151],
        "id": 329,
        "labels": [
            {"label": "Rhododendron ponticum", "language": "nl", "type": "prefLabel"},
            {"label": "Pontische rododendron", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 330,
        "labels": [
            {"label": "Rhus", "language": "la", "type": "prefLabel"},
            {"label": "azijnboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [331, 332, 333],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [330],
        "id": 331,
        "labels": [{"label": "Rhus potaninii", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [330],
        "id": 332,
        "labels": [
            {"label": "Rhus typhina", "language": "nl", "type": "prefLabel"},
            {"label": "fluweelboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [330],
        "id": 333,
        "labels": [
            {"label": "Rhus verniciflua", "language": "nl", "type": "prefLabel"},
            {"label": "vernisboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2154,
        "labels": [
            {"label": "Ribes", "language": "nl", "type": "prefLabel"},
            {"label": "bes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [442, 443, 444, 621],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2154],
        "id": 442,
        "labels": [
            {"label": "Ribes alpinum", "language": "nl", "type": "prefLabel"},
            {"label": "alpenbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2154],
        "id": 443,
        "labels": [
            {"label": "Ribes nigrum", "language": "nl", "type": "prefLabel"},
            {"label": "Europese zwarte bes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2154],
        "id": 444,
        "labels": [
            {"label": "Ribes rubrum", "language": "nl", "type": "prefLabel"},
            {"label": "gewone aalbes", "language": "nl", "type": "altLabel"},
            {"label": "trosbes", "language": "nl", "type": "altLabel"},
            {"label": "aalbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2154],
        "id": 621,
        "labels": [
            {"label": "Ribes uva-crispa", "language": "nl", "type": "prefLabel"},
            {"label": "kruisbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 334,
        "labels": [
            {"label": "Robinia", "language": "la", "type": "prefLabel"},
            {"label": "acacia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [335, 336, 337, 338, 341],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [334],
        "id": 335,
        "labels": [
            {"label": "Robinia fertilis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [334],
        "id": 336,
        "labels": [
            {"label": "Robinia hispida", "language": "nl", "type": "prefLabel"},
            {"label": "ruwe acacia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [334],
        "id": 337,
        "labels": [
            {"label": "Robinia luxurians", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [334],
        "id": 338,
        "labels": [
            {"label": "Robinia pseudoacacia", "language": "nl", "type": "prefLabel"},
            {"label": "gewone robinia", "language": "nl", "type": "altLabel"},
            {"label": "gewone acacia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [339, 340],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [338],
        "id": 339,
        "labels": [
            {
                "label": "Robinia pseudoacacia 'Tortuosa'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [338],
        "id": 340,
        "labels": [
            {
                "label": "Robinia pseudoacacia 'Umbraculifera'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "kogelacacia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [334],
        "id": 341,
        "labels": [
            {"label": "Robinia viscosa", "language": "nl", "type": "prefLabel"},
            {"label": "kleverige acacia", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 623,
        "labels": [
            {"label": "Rosa", "language": "la", "type": "prefLabel"},
            {"label": "roos", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [633],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [623],
        "id": 633,
        "labels": [
            {"label": "Rosa canina", "language": "nl", "type": "prefLabel"},
            {"label": "hondsroos", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 618,
        "labels": [
            {"label": "Rubus", "language": "la", "type": "prefLabel"},
            {"label": "braam", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 342,
        "labels": [
            {"label": "Salix", "language": "la", "type": "prefLabel"},
            {"label": "wilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            343,
            345,
            346,
            348,
            614,
            634,
            643,
            645,
            649,
            652,
            658,
            660,
            2160,
            2166,
            2167,
            2170,
            2171,
            2173,
            651,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 343,
        "labels": [
            {"label": "Salix alba", "language": "nl", "type": "prefLabel"},
            {"label": "schietwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 345,
        "labels": [
            {"label": "Salix babylonica", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2161],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [345],
        "id": 2161,
        "labels": [
            {
                "label": "Salix babylonica 'Tortuosa'",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "Salix matsudana 'Tortuosa'",
                "language": "nl",
                "type": "altLabel",
            },
            {"label": "krulwilg", "language": "nl", "type": "altLabel"},
            {"label": "kurkentrekkerwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 652,
        "labels": [
            {"label": "Salix caprea K.", "language": "nl", "type": "prefLabel"},
            {"label": "boswilg", "language": "nl", "type": "altLabel"},
            {"label": "waterwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 2166,
        "labels": [{"label": "Salix cinerea", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [640],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2166],
        "id": 640,
        "labels": [
            {
                "label": "Salix cinerea ssp. Cinerea",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "grauwe wilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 348,
        "labels": [
            {"label": "Salix daphnoides", "language": "nl", "type": "prefLabel"},
            {"label": "berijpte wilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 2167,
        "labels": [
            {"label": "Salix dasyclados", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [641, 661],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2167],
        "id": 641,
        "labels": [
            {
                "label": "Salix dasyclados var. Angustifolia cv Gewone kletters",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "gewone kletters", "language": "nl", "type": "altLabel"},
            {"label": "groene kletters", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2167],
        "id": 661,
        "labels": [
            {
                "label": "Salix dasyclados var. Angustifolia cv 'Kattekletters'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "Duitse dot", "language": "nl", "type": "altLabel"},
            {"label": "Kattekletters", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 614,
        "labels": [
            {"label": "Salix fragilis", "language": "nl", "type": "prefLabel"},
            {"label": "kraakwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [642],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [614],
        "id": 642,
        "labels": [
            {
                "label": "Salix fragilis L. var. Fragilis",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 658,
        "labels": [
            {"label": "Salix guinieri (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 2173,
        "labels": [
            {"label": "Salix mollissima", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [648, 659],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2173],
        "id": 659,
        "labels": [
            {
                "label": "Salix mollissima (x) var 'Behaarde twijg'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2173],
        "id": 648,
        "labels": [
            {
                "label": "Salix mollissima (x) var undulata",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 634,
        "labels": [
            {"label": "Salix multinervis (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 2170,
        "labels": [
            {"label": "Salix purpurea", "language": "nl", "type": "prefLabel"},
            {"label": "bittere wilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [644],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2170],
        "id": 644,
        "labels": [
            {
                "label": "Salix purpurea ssp. Lambertiana",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 649,
        "labels": [
            {"label": "Salix reichardtii (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 346,
        "labels": [
            {"label": "Salix rubens (x)", "language": "nl", "type": "prefLabel"},
            {"label": "gele bindwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [647],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [346],
        "id": 647,
        "labels": [
            {
                "label": "Salix rubens (x) var. Basforidiana forma basfordiana",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "gele Wijmen", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 660,
        "labels": [{"label": "Salix rubra (x)", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 2160,
        "labels": [
            {"label": "Salix sepulcralis (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [445],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2160],
        "id": 445,
        "labels": [
            {
                "label": "Salix sepulcralis (x) 'Chrysocoma'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "Salix alba 'Tristis'", "language": "nl", "type": "altLabel"},
            {"label": "gele treurwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 651,
        "labels": [
            {"label": "Salix smithiana (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 643,
        "labels": [
            {"label": "Salix triandra", "language": "nl", "type": "prefLabel"},
            {"label": "amandelwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [646],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [643],
        "id": 646,
        "labels": [
            {
                "label": "Salix triandra 'Zwarte reins'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 2171,
        "labels": [{"label": "Salix udensis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2172],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2171],
        "id": 2172,
        "labels": [
            {"label": "Salix udensis 'Sekka'", "language": "nl", "type": "prefLabel"},
            {
                "label": "Salix sachalinensis 'Sekka'",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Sachalinse wilg met bandvormig verbrede twijgen",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [342],
        "id": 645,
        "labels": [
            {"label": "Salix viminalis", "language": "nl", "type": "prefLabel"},
            {"label": "katwilg", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 667,
        "labels": [
            {"label": "Sambucus", "language": "la", "type": "prefLabel"},
            {"label": "vlier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [616, 665, 668],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [667],
        "id": 668,
        "labels": [
            {"label": "Sambucus ebulus", "language": "nl", "type": "prefLabel"},
            {"label": "kruidvlier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [667],
        "id": 616,
        "labels": [
            {"label": "Sambucus nigra", "language": "nl", "type": "prefLabel"},
            {"label": "gewone vlier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [667],
        "id": 665,
        "labels": [
            {"label": "Sambucus racemosa", "language": "nl", "type": "prefLabel"},
            {"label": "trosvlier", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2175,
        "labels": [{"label": "Sassafras", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2176],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2175],
        "id": 2176,
        "labels": [
            {"label": "Sassafras albidum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [350],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2176],
        "id": 350,
        "labels": [
            {
                "label": "Sassafras albidum var. molle",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "Amerikaanse sassafras", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2177,
        "labels": [{"label": "Sciadopitys", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [594],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2177],
        "id": 594,
        "labels": [
            {
                "label": "Sciadopitys verticillata",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "parasolden", "language": "nl", "type": "altLabel"},
            {"label": "kransspar", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1595,
        "labels": [{"label": "Sequoia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [595],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2179,
        "labels": [{"label": "Sequoiadendron", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [596],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2179],
        "id": 596,
        "labels": [
            {
                "label": "Sequoiadendron giganteum",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "mammoetboom", "language": "nl", "type": "altLabel"},
            {"label": "reuzensequoia", "language": "en", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1595],
        "id": 595,
        "labels": [
            {"label": "Sequoia sempervirens", "language": "nl", "type": "prefLabel"},
            {"label": "Coast redwood", "language": "en", "type": "altLabel"},
            {"label": "California redwood", "language": "en", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 355,
        "labels": [
            {"label": "Sorbus", "language": "la", "type": "prefLabel"},
            {"label": "lijsterbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            356,
            357,
            358,
            359,
            360,
            361,
            362,
            363,
            364,
            365,
            366,
            367,
            456,
            457,
            458,
            459,
            460,
            461,
            462,
            463,
            464,
            465,
            466,
            467,
            468,
            469,
        ],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 356,
        "labels": [
            {"label": "Sorbus alnifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 357,
        "labels": [
            {"label": "Sorbus americana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 358,
        "labels": [
            {"label": "Sorbus aria", "language": "nl", "type": "prefLabel"},
            {"label": "meelbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 359,
        "labels": [
            {"label": "Sorbus arnoldiana (x)", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 360,
        "labels": [
            {"label": "Sorbus arranensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 361,
        "labels": [
            {"label": "Sorbus aucuparia", "language": "nl", "type": "prefLabel"},
            {"label": "wilde lijsterbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 362,
        "labels": [
            {"label": "Sorbus austriaca", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 363,
        "labels": [{"label": "Sorbus commixta", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 364,
        "labels": [{"label": "Sorbus confusa", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 365,
        "labels": [
            {"label": "Sorbus cuspidata", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 366,
        "labels": [{"label": "Sorbus decora", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 367,
        "labels": [{"label": "Sorbus discolor", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 456,
        "labels": [
            {"label": "Sorbus domestica", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 457,
        "labels": [
            {"label": "Sorbus hupehensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 458,
        "labels": [{"label": "Sorbus hybrida", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 459,
        "labels": [
            {"label": "Sorbus intermedia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 460,
        "labels": [{"label": "Sorbus japonica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 461,
        "labels": [
            {"label": "Sorbus latifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 462,
        "labels": [
            {"label": "Sorbus mougeotii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 463,
        "labels": [
            {"label": "Sorbus pohuashanensis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 464,
        "labels": [
            {"label": "Sorbus rufoferruginea", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 465,
        "labels": [{"label": "Sorbus rupicola", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 466,
        "labels": [{"label": "Sorbus serotina", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 467,
        "labels": [
            {"label": "Sorbus thuringiaca (x)", "language": "nl", "type": "prefLabel"},
            {"label": "Gedeelde lijsterbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 468,
        "labels": [
            {"label": "Sorbus torminalis", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [355],
        "id": 469,
        "labels": [
            {"label": "Sorbus vilmorinii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2180,
        "labels": [{"label": "Staphylea", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [446, 447],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2180],
        "id": 446,
        "labels": [
            {"label": "Staphylea colchicum", "language": "nl", "type": "prefLabel"},
            {"label": "Kaukasische pimpernoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2180],
        "id": 447,
        "labels": [
            {"label": "Staphylea pinnata", "language": "nl", "type": "prefLabel"},
            {"label": "Europese pimpernoot", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2181,
        "labels": [{"label": "Stewartia", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [470],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2181],
        "id": 470,
        "labels": [
            {"label": "Stewartia pseudocamellia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2182],
        "id": 2183,
        "labels": [
            {
                "label": "Styphnolobia japonica 'Pendula'",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "Sophoria japonica 'Pendula'",
                "language": "nl",
                "type": "altLabel",
            },
            {"label": "treurhoningboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 351,
        "labels": [
            {"label": "Styphnolobium", "language": "nl", "type": "prefLabel"},
            {"label": "honingboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [352, 2182],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [351],
        "id": 352,
        "labels": [
            {"label": "Styphnolobium davidii", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [351],
        "id": 2182,
        "labels": [
            {"label": "Styphnolobium japonicum", "language": "nl", "type": "prefLabel"},
            {"label": "Sophoria japonica", "language": "nl", "type": "altLabel"},
            {"label": "Japanse honingboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2183],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2184,
        "labels": [{"label": "Symphoricarpos", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [448],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2184],
        "id": 448,
        "labels": [
            {"label": "Symphoricarpos albus", "language": "nl", "type": "prefLabel"},
            {"label": "sneeuwbes", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2185,
        "labels": [
            {"label": "Syringa", "language": "nl", "type": "prefLabel"},
            {"label": "sering", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [615],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2185],
        "id": 615,
        "labels": [
            {"label": "Syringa vulgaris", "language": "nl", "type": "prefLabel"},
            {"label": "gewone sering", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 597,
        "labels": [
            {"label": "Taxodium", "language": "la", "type": "prefLabel"},
            {"label": "moerascipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [598, 599],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [597],
        "id": 598,
        "labels": [
            {"label": "Taxodium ascendens", "language": "nl", "type": "prefLabel"},
            {"label": "vijvercipres", "language": "nl", "type": "altLabel"},
            {"label": "rijzige moerascipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [597],
        "id": 599,
        "labels": [
            {"label": "Taxodium distichum", "language": "nl", "type": "prefLabel"},
            {"label": "gewone moerascipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [449],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [599],
        "id": 449,
        "labels": [
            {
                "label": "Taxodium distichum 'Pendens'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Moerascipres, cultuurvari\xebteit met hangende twijgen",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 494,
        "labels": [
            {"label": "Taxus", "language": "la", "type": "prefLabel"},
            {"label": "venijnboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [600],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [494],
        "id": 600,
        "labels": [
            {"label": "Taxus baccata", "language": "nl", "type": "prefLabel"},
            {"label": "gewone taxus", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [450, 451],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [600],
        "id": 450,
        "labels": [
            {"label": "Taxus baccata 'Aurea'", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {"language": "nl", "note": "Taxus met geel jong blad", "type": "definition"}
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [600],
        "id": 451,
        "labels": [
            {
                "label": "Taxus baccata 'Fastigiata'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "Ierse taxus", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2189,
        "labels": [{"label": "Tetradium", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2190],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2189],
        "id": 2190,
        "labels": [
            {"label": "Tetradium daniellii", "language": "nl", "type": "prefLabel"},
            {"label": "Euodia hupehensis", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2191,
        "labels": [
            {"label": "Thuja", "language": "nl", "type": "prefLabel"},
            {"label": "levensboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [601, 602, 603, 604],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2191],
        "id": 601,
        "labels": [
            {"label": "Thuja occidentalis", "language": "nl", "type": "prefLabel"},
            {"label": "westerse levensboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2191],
        "id": 602,
        "labels": [
            {"label": "Thuja orientalis", "language": "nl", "type": "prefLabel"},
            {"label": "Oosterse levensboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2191],
        "id": 603,
        "labels": [
            {"label": "Thuja plicata", "language": "nl", "type": "prefLabel"},
            {"label": "reuzenlevensboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [452],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [603],
        "id": 452,
        "labels": [
            {"label": "Thuja plicata 'Zebrina'", "language": "nl", "type": "prefLabel"},
            {
                "label": "Goudbonte reuzenlevensboom",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2191],
        "id": 604,
        "labels": [
            {"label": "Thuja standishii", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse levensboom", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2193,
        "labels": [{"label": "Thujopsis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [605],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2193],
        "id": 605,
        "labels": [
            {"label": "Thujopsis dolabrata", "language": "nl", "type": "prefLabel"},
            {"label": "Hibacipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 471,
        "labels": [
            {"label": "Tilia", "language": "la", "type": "prefLabel"},
            {"label": "linde", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [472, 473, 475, 477, 478],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [471],
        "id": 472,
        "labels": [
            {"label": "Tilia americana", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse linde", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [471],
        "id": 473,
        "labels": [
            {"label": "Tilia cordata", "language": "nl", "type": "prefLabel"},
            {"label": "winterlinde", "language": "nl", "type": "altLabel"},
            {"label": "kleinbladige linde", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 479,
        "labels": [
            {"label": "Tilia europaea (x)", "language": "nl", "type": "prefLabel"},
            {"label": "Hollandse linde", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [474],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [479],
        "id": 474,
        "labels": [
            {
                "label": "Tilia europaea (x) 'Euchlora'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "Krimlinde", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [471],
        "id": 475,
        "labels": [
            {"label": "Tilia miqueliana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [471],
        "id": 477,
        "labels": [
            {"label": "Tilia platyphyllos", "language": "nl", "type": "prefLabel"},
            {"label": "zomerlinde", "language": "nl", "type": "altLabel"},
            {"label": "grootbladige linde", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [453, 454],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [477],
        "id": 453,
        "labels": [
            {
                "label": "Tilia platyphyllos 'Laciniata'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Zomerlinde met ingesneden blad",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [477],
        "id": 454,
        "labels": [
            {
                "label": "Tilia platyphyllos 'Vitifolia'",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "wingerdbladige zomerlinde",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [471],
        "id": 478,
        "labels": [
            {"label": "Tilia tomentosa", "language": "nl", "type": "prefLabel"},
            {"label": "zilverlinde", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [476, 627],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [478],
        "id": 627,
        "labels": [
            {
                "label": "Tilia tomentosa 'Brabant'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [478],
        "id": 476,
        "labels": [
            {
                "label": "Tilia tomentosa 'Pendula'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "hangende zilverlinde", "language": "nl", "type": "altLabel"},
            {"label": "Tilia petiolaris", "language": "nl", "type": "altLabel"},
            {"label": "Hongaarse zilverlinde", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2198,
        "labels": [{"label": "Toona", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2199],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2198],
        "id": 2199,
        "labels": [
            {"label": "Toona sinensis", "language": "nl", "type": "prefLabel"},
            {"label": "Cedrela sinensis", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1606,
        "labels": [{"label": "Torreya", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [455, 606],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1606],
        "id": 455,
        "labels": [
            {"label": "Torreya californica", "language": "nl", "type": "prefLabel"},
            {"label": "Californische torreya", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1606],
        "id": 606,
        "labels": [
            {"label": "Torreya nucifera", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 607,
        "labels": [
            {"label": "Tsuga", "language": "la", "type": "prefLabel"},
            {"label": "scheerlingsden", "language": "nl", "type": "altLabel"},
            {"label": "Hemlock", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [608, 609, 610, 611, 612, 613],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [607],
        "id": 608,
        "labels": [
            {"label": "Tsuga canadensis", "language": "nl", "type": "prefLabel"},
            {"label": "Canadese Hemlock", "language": "nl", "type": "altLabel"},
            {
                "label": "Oost-Amerikaanse hemlockspar",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [607],
        "id": 609,
        "labels": [
            {"label": "Tsuga caroliniana", "language": "nl", "type": "prefLabel"},
            {"label": "Carolina hemlock", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [607],
        "id": 610,
        "labels": [
            {"label": "Tsuga diversifolia", "language": "nl", "type": "prefLabel"},
            {"label": "Noord-Japanse hemlock", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [607],
        "id": 611,
        "labels": [
            {"label": "Tsuga heterophylla", "language": "nl", "type": "prefLabel"},
            {"label": "Westerse hemlock", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [607],
        "id": 612,
        "labels": [
            {"label": "Tsuga mertensiana", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [607],
        "id": 613,
        "labels": [
            {"label": "Tsuga sieboldii", "language": "nl", "type": "prefLabel"},
            {"label": "Zuid-Japanse hemlock", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 480,
        "labels": [
            {"label": "Ulmus", "language": "la", "type": "prefLabel"},
            {"label": "iep", "language": "nl", "type": "altLabel"},
            {"label": "olm", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [481, 482, 483, 484, 488, 489, 490, 491, 487],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 481,
        "labels": [
            {"label": "Ulmus americana", "language": "nl", "type": "prefLabel"},
            {"label": "Amerikaanse iep", "language": "nl", "type": "altLabel"},
            {"label": "Amerikaanse olm", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 483,
        "labels": [{"label": "Ulmus elliptica", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 484,
        "labels": [
            {"label": "Ulmus glabra", "language": "nl", "type": "prefLabel"},
            {"label": "ruwe iep", "language": "nl", "type": "altLabel"},
            {"label": "bergiep", "language": "nl", "type": "altLabel"},
            {"label": "ruwe olm", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [485, 630, 2206],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [484],
        "id": 485,
        "labels": [
            {
                "label": "Ulmus glabra 'Camperdownii'",
                "language": "nl",
                "type": "prefLabel",
            },
            {"label": "prieeliep", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [484],
        "id": 630,
        "labels": [
            {"label": "Ulmus glabra 'Cornuta'", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [484],
        "id": 2206,
        "labels": [
            {"label": "Ulmus glabra 'Pendula'", "language": "nl", "type": "prefLabel"},
            {
                "label": "Ulmus glabra 'Horizontalis'",
                "language": "nl",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 487,
        "labels": [
            {"label": "Ulmus hollandica (x)", "language": "nl", "type": "prefLabel"},
            {"label": "Hollandse iep", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [635, 636, 637],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [487],
        "id": 636,
        "labels": [
            {
                "label": "Ulmus hollandica (x) 'Belgica'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [487],
        "id": 635,
        "labels": [
            {
                "label": "Ulmus hollandica (x) 'Major'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [487],
        "id": 637,
        "labels": [
            {
                "label": "Ulmus hollandica (x) 'Vegeta'",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 488,
        "labels": [
            {"label": "Ulmus laevis", "language": "nl", "type": "prefLabel"},
            {"label": "fladderiep", "language": "nl", "type": "altLabel"},
            {"label": "steeliep", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 482,
        "labels": [
            {"label": "Ulmus minor", "language": "nl", "type": "prefLabel"},
            {"label": "gladde iep", "language": "nl", "type": "altLabel"},
            {"label": "veldiep", "language": "nl", "type": "altLabel"},
            {"label": "gladde olm", "language": "nl", "type": "altLabel"},
            {"label": "Ulmus carpinifolia", "language": "nl", "type": "altLabel"},
            {"label": "Ulmus campestris", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 489,
        "labels": [
            {"label": "Ulmus parvifolia", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 490,
        "labels": [
            {"label": "Ulmus procera", "language": "nl", "type": "prefLabel"},
            {"label": "Engelse veldiep", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [480],
        "id": 491,
        "labels": [{"label": "Ulmus pumila", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2212,
        "labels": [{"label": "Viburnum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [669],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2212],
        "id": 669,
        "labels": [
            {"label": "Viburnum opulus", "language": "nl", "type": "prefLabel"},
            {"label": "Gelderse Roos", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2332,
        "labels": [{"label": "Vitis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2333],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2332],
        "id": 2333,
        "labels": [
            {"label": "Vitis vinifera", "language": "nl", "type": "prefLabel"},
            {"label": "Europese wijnstok", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2213,
        "labels": [{"label": "Xanthocyparis", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2214],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2213],
        "id": 2214,
        "labels": [
            {
                "label": "Xanthocyparis nootkatensis",
                "language": "nl",
                "type": "prefLabel",
            },
            {
                "label": "Chamaecyparis nootkatensis",
                "language": "nl",
                "type": "altLabel",
            },
            {"label": "nootkaschijncipres", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 2215,
        "labels": [{"label": "Zelkova", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [492, 493],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2215],
        "id": 492,
        "labels": [
            {"label": "Zelkova carpinifolia", "language": "nl", "type": "prefLabel"},
            {"label": "Kaukasische zelkova", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [2215],
        "id": 493,
        "labels": [
            {"label": "Zelkova serrata", "language": "nl", "type": "prefLabel"},
            {"label": "Japanse zelkova", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
]
